# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'xulpymoney/ui/frmSettings.ui'
#
# Created by: PyQt5 UI code generator 5.12.2
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_frmSettings(object):
    def setupUi(self, frmSettings):
        frmSettings.setObjectName("frmSettings")
        frmSettings.setWindowModality(QtCore.Qt.WindowModal)
        frmSettings.resize(567, 428)
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(":/xulpymoney/save.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        frmSettings.setWindowIcon(icon)
        frmSettings.setSizeGripEnabled(True)
        frmSettings.setModal(True)
        self.horizontalLayout_7 = QtWidgets.QHBoxLayout(frmSettings)
        self.horizontalLayout_7.setObjectName("horizontalLayout_7")
        self.verticalLayout = QtWidgets.QVBoxLayout()
        self.verticalLayout.setObjectName("verticalLayout")
        self.lblTitulo = QtWidgets.QLabel(frmSettings)
        font = QtGui.QFont()
        font.setPointSize(14)
        font.setBold(True)
        font.setWeight(75)
        self.lblTitulo.setFont(font)
        self.lblTitulo.setAlignment(QtCore.Qt.AlignCenter)
        self.lblTitulo.setObjectName("lblTitulo")
        self.verticalLayout.addWidget(self.lblTitulo)
        self.horizontalLayout_4 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_4.setObjectName("horizontalLayout_4")
        spacerItem = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_4.addItem(spacerItem)
        self.lblPixmap = QtWidgets.QLabel(frmSettings)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.lblPixmap.sizePolicy().hasHeightForWidth())
        self.lblPixmap.setSizePolicy(sizePolicy)
        self.lblPixmap.setMinimumSize(QtCore.QSize(48, 48))
        self.lblPixmap.setMaximumSize(QtCore.QSize(48, 48))
        self.lblPixmap.setPixmap(QtGui.QPixmap(":/xulpymoney/configure.png"))
        self.lblPixmap.setScaledContents(True)
        self.lblPixmap.setAlignment(QtCore.Qt.AlignCenter)
        self.lblPixmap.setObjectName("lblPixmap")
        self.horizontalLayout_4.addWidget(self.lblPixmap)
        spacerItem1 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_4.addItem(spacerItem1)
        self.verticalLayout.addLayout(self.horizontalLayout_4)
        self.groupBox_2 = QtWidgets.QGroupBox(frmSettings)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupBox_2.sizePolicy().hasHeightForWidth())
        self.groupBox_2.setSizePolicy(sizePolicy)
        self.groupBox_2.setObjectName("groupBox_2")
        self.horizontalLayout_8 = QtWidgets.QHBoxLayout(self.groupBox_2)
        self.horizontalLayout_8.setObjectName("horizontalLayout_8")
        self.verticalLayout_4 = QtWidgets.QVBoxLayout()
        self.verticalLayout_4.setObjectName("verticalLayout_4")
        self.horizontalLayout_9 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_9.setObjectName("horizontalLayout_9")
        self.label_4 = QtWidgets.QLabel(self.groupBox_2)
        self.label_4.setObjectName("label_4")
        self.horizontalLayout_9.addWidget(self.label_4)
        self.cmbLanguages = QtWidgets.QComboBox(self.groupBox_2)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.cmbLanguages.sizePolicy().hasHeightForWidth())
        self.cmbLanguages.setSizePolicy(sizePolicy)
        self.cmbLanguages.setObjectName("cmbLanguages")
        self.horizontalLayout_9.addWidget(self.cmbLanguages)
        self.verticalLayout_4.addLayout(self.horizontalLayout_9)
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.label = QtWidgets.QLabel(self.groupBox_2)
        self.label.setObjectName("label")
        self.horizontalLayout.addWidget(self.label)
        self.cmbCurrencies = QtWidgets.QComboBox(self.groupBox_2)
        self.cmbCurrencies.setObjectName("cmbCurrencies")
        self.horizontalLayout.addWidget(self.cmbCurrencies)
        self.verticalLayout_4.addLayout(self.horizontalLayout)
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.label_2 = QtWidgets.QLabel(self.groupBox_2)
        self.label_2.setObjectName("label_2")
        self.horizontalLayout_2.addWidget(self.label_2)
        self.cmbZones = QtWidgets.QComboBox(self.groupBox_2)
        self.cmbZones.setObjectName("cmbZones")
        self.horizontalLayout_2.addWidget(self.cmbZones)
        self.verticalLayout_4.addLayout(self.horizontalLayout_2)
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.label_3 = QtWidgets.QLabel(self.groupBox_2)
        self.label_3.setObjectName("label_3")
        self.horizontalLayout_3.addWidget(self.label_3)
        self.cmbIndex = QtWidgets.QComboBox(self.groupBox_2)
        self.cmbIndex.setObjectName("cmbIndex")
        self.horizontalLayout_3.addWidget(self.cmbIndex)
        self.verticalLayout_4.addLayout(self.horizontalLayout_3)
        self.horizontalLayout_5 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_5.setObjectName("horizontalLayout_5")
        self.label_5 = QtWidgets.QLabel(self.groupBox_2)
        self.label_5.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.label_5.setObjectName("label_5")
        self.horizontalLayout_5.addWidget(self.label_5)
        self.spnDividendPercentage = QtWidgets.QDoubleSpinBox(self.groupBox_2)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.spnDividendPercentage.sizePolicy().hasHeightForWidth())
        self.spnDividendPercentage.setSizePolicy(sizePolicy)
        self.spnDividendPercentage.setMinimumSize(QtCore.QSize(200, 0))
        self.spnDividendPercentage.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.spnDividendPercentage.setDecimals(2)
        self.spnDividendPercentage.setSingleStep(0.1)
        self.spnDividendPercentage.setProperty("value", 21.0)
        self.spnDividendPercentage.setObjectName("spnDividendPercentage")
        self.horizontalLayout_5.addWidget(self.spnDividendPercentage)
        self.verticalLayout_4.addLayout(self.horizontalLayout_5)
        self.horizontalLayout_6 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_6.setObjectName("horizontalLayout_6")
        self.label_6 = QtWidgets.QLabel(self.groupBox_2)
        self.label_6.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.label_6.setObjectName("label_6")
        self.horizontalLayout_6.addWidget(self.label_6)
        self.spnGainsPercentaje = QtWidgets.QDoubleSpinBox(self.groupBox_2)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.spnGainsPercentaje.sizePolicy().hasHeightForWidth())
        self.spnGainsPercentaje.setSizePolicy(sizePolicy)
        self.spnGainsPercentaje.setMinimumSize(QtCore.QSize(200, 0))
        self.spnGainsPercentaje.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.spnGainsPercentaje.setDecimals(2)
        self.spnGainsPercentaje.setSingleStep(0.1)
        self.spnGainsPercentaje.setProperty("value", 21.0)
        self.spnGainsPercentaje.setObjectName("spnGainsPercentaje")
        self.horizontalLayout_6.addWidget(self.spnGainsPercentaje)
        self.verticalLayout_4.addLayout(self.horizontalLayout_6)
        self.chkGainsYear = QtWidgets.QCheckBox(self.groupBox_2)
        self.chkGainsYear.setObjectName("chkGainsYear")
        self.verticalLayout_4.addWidget(self.chkGainsYear)
        self.horizontalLayout_10 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_10.setObjectName("horizontalLayout_10")
        self.label_7 = QtWidgets.QLabel(self.groupBox_2)
        self.label_7.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.label_7.setObjectName("label_7")
        self.horizontalLayout_10.addWidget(self.label_7)
        self.spnGainsPercentajeBelow = QtWidgets.QDoubleSpinBox(self.groupBox_2)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.spnGainsPercentajeBelow.sizePolicy().hasHeightForWidth())
        self.spnGainsPercentajeBelow.setSizePolicy(sizePolicy)
        self.spnGainsPercentajeBelow.setMinimumSize(QtCore.QSize(200, 0))
        self.spnGainsPercentajeBelow.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.spnGainsPercentajeBelow.setDecimals(2)
        self.spnGainsPercentajeBelow.setSingleStep(0.1)
        self.spnGainsPercentajeBelow.setProperty("value", 50.0)
        self.spnGainsPercentajeBelow.setObjectName("spnGainsPercentajeBelow")
        self.horizontalLayout_10.addWidget(self.spnGainsPercentajeBelow)
        self.verticalLayout_4.addLayout(self.horizontalLayout_10)
        self.horizontalLayout_8.addLayout(self.verticalLayout_4)
        self.verticalLayout.addWidget(self.groupBox_2)
        self.buttonbox = QtWidgets.QDialogButtonBox(frmSettings)
        self.buttonbox.setStandardButtons(QtWidgets.QDialogButtonBox.Cancel|QtWidgets.QDialogButtonBox.Ok)
        self.buttonbox.setObjectName("buttonbox")
        self.verticalLayout.addWidget(self.buttonbox)
        self.horizontalLayout_7.addLayout(self.verticalLayout)

        self.retranslateUi(frmSettings)
        QtCore.QMetaObject.connectSlotsByName(frmSettings)

    def retranslateUi(self, frmSettings):
        _translate = QtCore.QCoreApplication.translate
        frmSettings.setWindowTitle(_translate("frmSettings", "Xulpymoney settings"))
        self.lblTitulo.setText(_translate("frmSettings", "Xulpymoney settings"))
        self.groupBox_2.setTitle(_translate("frmSettings", "User settings"))
        self.label_4.setText(_translate("frmSettings", "Select a language"))
        self.label.setText(_translate("frmSettings", "Main currency"))
        self.label_2.setText(_translate("frmSettings", "User datetime zone"))
        self.label_3.setText(_translate("frmSettings", "Benchmark"))
        self.label_5.setText(_translate("frmSettings", "Dividend withholding percentage"))
        self.spnDividendPercentage.setSuffix(_translate("frmSettings", " %"))
        self.label_6.setText(_translate("frmSettings", "Tax gain percentage"))
        self.spnGainsPercentaje.setSuffix(_translate("frmSettings", " %"))
        self.chkGainsYear.setText(_translate("frmSettings", "Capital gains over a year have a different tax"))
        self.label_7.setText(_translate("frmSettings", "Tax gain percentage below a year"))
        self.spnGainsPercentajeBelow.setSuffix(_translate("frmSettings", " %"))


import xulpymoney.images.xulpymoney_rc



from xulpymoney.libxulpymoneyfunctions import qmessagebox
from xulpymoney.libxulpymoney import Percentage
from PyQt5.QtCore import QSize, pyqtSlot
from PyQt5.QtWidgets import QDialog, QMenu, QVBoxLayout, QWidget
from xulpymoney.ui.Ui_wdgLastCurrent import Ui_wdgLastCurrent
from xulpymoney.ui.frmInvestmentReport import frmInvestmentReport
from xulpymoney.ui.frmProductReport import frmProductReport
from xulpymoney.ui.wdgCalculator import wdgCalculator
from xulpymoney.ui.wdgDisReinvest import wdgDisReinvest
from decimal import Decimal

class wdgLastCurrent(QWidget, Ui_wdgLastCurrent):
    def __init__(self, mem,  parent=None):
        QWidget.__init__(self, parent)
        self.setupUi(self)
        self.mem=mem
        self.investments=None
        self.tblInvestments.settings(self.mem, "wdgLastCurrent")
        self.spin.setValue(int(self.mem.settingsdb.value("wdgLastCurrent/spin", "-25")))
        self.on_cmbSameProduct_currentIndexChanged(int(self.mem.settingsdb.value("wdgLastCurrent/viewode", 0)))
        
    def tblInvestments_reload(self):
        self.investments.myqtablewidget_lastCurrent(self.tblInvestments, Percentage(self.spin.value(), 100))

    @pyqtSlot() 
    def on_actionInvestmentReport_triggered(self):
        w=frmInvestmentReport(self.mem, self.investments.selected, self)
        w.exec_()
        self.tblInvestments_reload()
        
    @pyqtSlot() 
    def on_actionCalculate_triggered(self):
        d=QDialog(self)        
        d.setFixedSize(850, 850)
        d.setWindowTitle(self.tr("Investment last operation calculator"))
        w=wdgCalculator(self.mem)
        w.setInvestment(self.investments.selected)
        price=self.investments.selected.op_actual.last().valor_accion*(1+self.spin.value()/Decimal(100))#Is + because -·-
        w.txtFinalPrice.setText(price)
        lay = QVBoxLayout(d)
        lay.addWidget(w)
        d.show()        
        
    @pyqtSlot() 
    def on_actionReinvest_triggered(self):
        d=QDialog()       
        d.resize(self.mem.settings.value("frmInvestmentReport/qdialog_disreinvest", QSize(1024, 768)))
        d.setWindowTitle(self.tr("Divest / Reinvest simulation"))
        w=wdgDisReinvest(self.mem, self.investments.selected, False,  d)
        price=self.investments.selected.op_actual.last().valor_accion*(1+self.spin.value()/Decimal(100))#Is + because -·-        
        w.txtValorAccion.setText(price)
        lay = QVBoxLayout(d)
        lay.addWidget(w)
        d.exec_()
        self.mem.settings.setValue("frmInvestmentReport/qdialog_disreinvest", d.size())        
        
    @pyqtSlot() 
    def on_actionReinvestCurrent_triggered(self):
        d=QDialog()       
        d.resize(self.mem.settings.value("frmInvestmentReport/qdialog_disreinvest", QSize(1024, 768)))
        d.setWindowTitle(self.tr("Divest / Reinvest simulation"))
        w=wdgDisReinvest(self.mem, self.investments.selected, False,  d)
        lay = QVBoxLayout(d)
        lay.addWidget(w)
        d.exec_()
        self.mem.settings.setValue("frmInvestmentReport/qdialog_disreinvest", d.size())
                
    @pyqtSlot() 
    def on_actionProduct_triggered(self):
        w=frmProductReport(self.mem, self.investments.selected.product, self.investments.selected, self)
        w.exec_()
        self.tblInvestments_reload()
      
   
    @pyqtSlot() 
    def on_actionSortTPCVenta_triggered(self):
        if self.investments.order_by_percentage_sellingpoint()==False:
            qmessagebox(self.tr("I couldn't order data due to they have null values"))     
        self.tblInvestments_reload()
        
    @pyqtSlot() 
    def on_actionSortTPC_triggered(self):
        if self.investments.order_by_percentage_invested()==False:
            qmessagebox(self.tr("I couldn't order data due to they have null values"))     
        self.tblInvestments_reload()
        
    @pyqtSlot() 
    def on_actionSortHour_triggered(self):
        if self.investments.order_by_datetime_last_operation()==False:
            qmessagebox(self.tr("I couldn't order data due to they have null values"))     
        self.tblInvestments_reload()
        
    @pyqtSlot() 
    def on_actionSortName_triggered(self):            
        if self.investments.order_by_name()==False:
            qmessagebox(self.tr("I couldn't order data due to they have null values"))     
        self.tblInvestments_reload()    

    @pyqtSlot() 
    def on_actionSortTPCLast_triggered(self):
        if self.investments.order_by_percentage_last_operation()==False:
            qmessagebox(self.tr("I couldn't order data due to they have null values"))     
        self.tblInvestments_reload()    
            

    def on_tblInvestments_customContextMenuRequested(self,  pos):
        if self.investments.selected==None:
            self.actionInvestmentReport.setEnabled(False)
            self.actionProduct.setEnabled(False)
        else:
            self.actionInvestmentReport.setEnabled(True)
            self.actionProduct.setEnabled(True)


        self.actionCalculate.setText("Calculate order at {} % since last operation".format(self.spin.value()))
        self.actionReinvest.setText("Simulate reinvestment at {} % since last operation".format(self.spin.value()))
        menu=QMenu()
        menu.addAction(self.actionCalculate)
        menu.addSeparator()
        menu.addAction(self.actionReinvestCurrent)
        menu.addAction(self.actionReinvest)
        menu.addSeparator()
        menu.addAction(self.actionInvestmentReport)        
        menu.addAction(self.actionProduct)
        menu.addSeparator()
        ordenar=QMenu(self.tr("Order by"))
        ordenar.addAction(self.actionSortName)
        ordenar.addAction(self.actionSortHour)
        ordenar.addAction(self.actionSortTPCLast)
        ordenar.addAction(self.actionSortTPC)
        ordenar.addAction(self.actionSortTPCVenta)
        menu.addMenu(ordenar)        
        menu.exec_(self.tblInvestments.mapToGlobal(pos))

    def on_cmd_released(self):
        self.tblInvestments_reload()
        self.mem.settingsdb.setValue("wdgLastCurrent/spin", self.spin.value())

    def on_tblInvestments_itemSelectionChanged(self):
        self.investments.selected=None
        for i in self.tblInvestments.selectedItems():#itera por cada item no row.
            self.investments.selected=self.investments.arr[i.row()]

    @pyqtSlot(int)
    def on_cmbSameProduct_currentIndexChanged(self, index):
        self.cmbSameProduct.setCurrentIndex(index)
        if index==0:
            self.investments=self.mem.data.investments_active()
            self.on_actionSortTPCLast_triggered()
        elif index==1:
            self.investments=self.mem.data.investments_active().setInvestments_merging_investments_with_same_product_merging_current_operations()
            self.on_actionSortTPCLast_triggered()
        elif index==2:
            self.investments=self.mem.data.investments_active().setInvestments_merging_investments_with_same_product_merging_operations()
            self.on_actionSortTPCLast_triggered()
            self.tblInvestments_reload()
        self.mem.settingsdb.setValue("wdgLastCurrent/viewode", index)



from PyQt5.QtCore import pyqtSignal,  pyqtSlot
from PyQt5.QtWidgets import QWidget
import datetime
from xulpymoney.ui.Ui_wdgDatetime import Ui_wdgDatetime
from xulpymoney.libxulpymoneyfunctions import dtaware

class wdgDatetime(QWidget, Ui_wdgDatetime):
    """Usage:
    Use constructor wdgDatetime()
    Set if show seconds, microseconds, zone
    Use set function to set the zone
    """
    changed=pyqtSignal()
    def __init__(self,  parent = None, name = None):
        QWidget.__init__(self,  parent)
        self.setupUi(self)
        self.mem=None
        self.teMicroseconds.setSuffix(self.tr(" \u03bcs"))        
        self.showMicroseconds=True
        self.showSeconds=True
        self.showZone=True
        self.zone=None#Set in set()                                                                                                     
        
    def show_microseconds(self, show):
        self.showMicroseconds=show
        if show==True:
            self.teMicroseconds.show()
        else:
            self.teMicroseconds.hide()
    
    def show_seconds(self, show):
        """Hides seconds when show is True. The datetime funtion the hour with zero seconds.
        show_seconds(False) doestn't implies show_microseconds(False). You must added manually."""
        self.showSeconds=show
        if show==True:
            self.teTime.setDisplayFormat("HH:mm:ss")
        else:
            self.teTime.setDisplayFormat("HH:mm")
        
    def show_timezone(self, show):
        """Hiding this all zones will have localzone defined in self.mem.localzone"""
        self.showZone=show
        if show==True:
            self.cmbZone.show()
        else:
            self.cmbZone.hide()
            
    def on_cmdNow_released(self):
        self.set(self.mem, datetime.datetime.now(), self.mem.localzone)

    def setTitle(self, title):
        self.grp.setTitle(title)

    def setCombine(self, mem, date, time, zone):
        """Use datetime combine to pass date and time"""
        self.set(mem, datetime.datetime.combine(date, time), zone)


    def set(self,  mem, dt=None,  zone=None):
        """Can be called several times"""
        self.mem=mem
        if self.cmbZone.count()==0:#Load combo zone, before, problems with on_changed
            self.mem.zones.qcombobox(self.cmbZone)  
            
        if dt==None or zone==None:
            self.on_cmdNow_released()
            return
            
        if self.showZone==False:
            self.on_cmbZone_currentIndexChanged(self.mem.localzone.name)
        else:
            self.on_cmbZone_currentIndexChanged(zone.name)
        
        self.teDate.setSelectedDate(dt.date())
        
        if self.showSeconds==False:
            dt=dt.replace(second=0)
        self.teTime.setTime(dt.time())
        
        if self.showMicroseconds==False:
            dt=dt.replace(microsecond=0)
        self.teMicroseconds.setValue(dt.microsecond)
        
        self.updateTooltip()
        self.changed.emit()
        
        
    def date(self):
        return self.teDate.selectedDate().toPyDate()
        
    def datetime(self):
        #qt only miliseconds
        time=self.teTime.time().toPyTime()
        time=time.replace(microsecond=self.teMicroseconds.value())
        return dtaware(self.teDate.selectedDate().toPyDate(), time , self.zone.name)

    def on_teDate_selectionChanged(self):
        self.updateTooltip()
        self.changed.emit()
        
    def on_teTime_timeChanged(self, time):
        self.updateTooltip()
        self.changed.emit()
        
    @pyqtSlot(int)   
    def on_teMicroseconds_valueChanged(self):
        self.updateTooltip()
        self.changed.emit()
        
    @pyqtSlot(str)      
    def on_cmbZone_currentIndexChanged(self, stri):
        self.zone=self.mem.zones.find_by_name(stri)
        self.updateTooltip()
        self.changed.emit()
        
    def updateTooltip(self):
        self.setToolTip(self.tr("Selected datetime:\n{0}").format(self.datetime()))

        




# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'xulpymoney/ui/wdgInvestmentsRanking.ui'
#
# Created by: PyQt5 UI code generator 5.12.2
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_wdgInvestmentsRanking(object):
    def setupUi(self, wdgInvestmentsRanking):
        wdgInvestmentsRanking.setObjectName("wdgInvestmentsRanking")
        wdgInvestmentsRanking.resize(750, 524)
        self.horizontalLayout = QtWidgets.QHBoxLayout(wdgInvestmentsRanking)
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.verticalLayout = QtWidgets.QVBoxLayout()
        self.verticalLayout.setObjectName("verticalLayout")
        self.lbl = QtWidgets.QLabel(wdgInvestmentsRanking)
        font = QtGui.QFont()
        font.setPointSize(14)
        font.setBold(True)
        font.setWeight(75)
        self.lbl.setFont(font)
        self.lbl.setAlignment(QtCore.Qt.AlignCenter)
        self.lbl.setObjectName("lbl")
        self.verticalLayout.addWidget(self.lbl)
        self.tab = QtWidgets.QTabWidget(wdgInvestmentsRanking)
        self.tab.setContextMenuPolicy(QtCore.Qt.CustomContextMenu)
        self.tab.setObjectName("tab")
        self.tab_ = QtWidgets.QWidget()
        self.tab_.setObjectName("tab_")
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout(self.tab_)
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.tblCurrentOperations = myQTableWidget(self.tab_)
        self.tblCurrentOperations.setContextMenuPolicy(QtCore.Qt.CustomContextMenu)
        self.tblCurrentOperations.setAlternatingRowColors(True)
        self.tblCurrentOperations.setSelectionMode(QtWidgets.QAbstractItemView.SingleSelection)
        self.tblCurrentOperations.setSelectionBehavior(QtWidgets.QAbstractItemView.SelectRows)
        self.tblCurrentOperations.setObjectName("tblCurrentOperations")
        self.tblCurrentOperations.setColumnCount(0)
        self.tblCurrentOperations.setRowCount(0)
        self.horizontalLayout_3.addWidget(self.tblCurrentOperations)
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(":/xulpymoney/crown.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.tab.addTab(self.tab_, icon, "")
        self.tab_2 = QtWidgets.QWidget()
        self.tab_2.setObjectName("tab_2")
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout(self.tab_2)
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.tblOperations = myQTableWidget(self.tab_2)
        self.tblOperations.setContextMenuPolicy(QtCore.Qt.CustomContextMenu)
        self.tblOperations.setSelectionMode(QtWidgets.QAbstractItemView.SingleSelection)
        self.tblOperations.setSelectionBehavior(QtWidgets.QAbstractItemView.SelectRows)
        self.tblOperations.setObjectName("tblOperations")
        self.tblOperations.setColumnCount(0)
        self.tblOperations.setRowCount(0)
        self.horizontalLayout_2.addWidget(self.tblOperations)
        self.tab.addTab(self.tab_2, icon, "")
        self.verticalLayout.addWidget(self.tab)
        self.horizontalLayout.addLayout(self.verticalLayout)
        self.actionSameProduct = QtWidgets.QAction(wdgInvestmentsRanking)
        icon1 = QtGui.QIcon()
        icon1.addPixmap(QtGui.QPixmap(":/xulpymoney/bundle.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionSameProduct.setIcon(icon1)
        self.actionSameProduct.setObjectName("actionSameProduct")
        self.actionSameProductFIFO = QtWidgets.QAction(wdgInvestmentsRanking)
        self.actionSameProductFIFO.setIcon(icon1)
        self.actionSameProductFIFO.setObjectName("actionSameProductFIFO")
        self.actionProduct = QtWidgets.QAction(wdgInvestmentsRanking)
        icon2 = QtGui.QIcon()
        icon2.addPixmap(QtGui.QPixmap(":/xulpymoney/books.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionProduct.setIcon(icon2)
        self.actionProduct.setObjectName("actionProduct")

        self.retranslateUi(wdgInvestmentsRanking)
        self.tab.setCurrentIndex(0)
        QtCore.QMetaObject.connectSlotsByName(wdgInvestmentsRanking)

    def retranslateUi(self, wdgInvestmentsRanking):
        _translate = QtCore.QCoreApplication.translate
        self.lbl.setText(_translate("wdgInvestmentsRanking", "Investments ranking"))
        self.tab.setTabText(self.tab.indexOf(self.tab_), _translate("wdgInvestmentsRanking", "With same product merging current operations"))
        self.tab.setTabText(self.tab.indexOf(self.tab_2), _translate("wdgInvestmentsRanking", "With same product merging operations"))
        self.actionSameProduct.setText(_translate("wdgInvestmentsRanking", "Same product Investments merging current operations"))
        self.actionSameProduct.setToolTip(_translate("wdgInvestmentsRanking", "Same product Investments merging current operations"))
        self.actionSameProductFIFO.setText(_translate("wdgInvestmentsRanking", "Same product Investments merging operations"))
        self.actionSameProductFIFO.setToolTip(_translate("wdgInvestmentsRanking", "Same product Investments merging operations"))
        self.actionProduct.setText(_translate("wdgInvestmentsRanking", "Product report"))
        self.actionProduct.setToolTip(_translate("wdgInvestmentsRanking", "Product report"))


from xulpymoney.ui.myqtablewidget import myQTableWidget
import xulpymoney.images.xulpymoney_rc



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'xulpymoney/ui/frmHelp.ui'
#
# Created by: PyQt5 UI code generator 5.12.2
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_frmHelp(object):
    def setupUi(self, frmHelp):
        frmHelp.setObjectName("frmHelp")
        frmHelp.resize(1078, 851)
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(":/xulpymoney/books.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        frmHelp.setWindowIcon(icon)
        frmHelp.setSizeGripEnabled(True)
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout(frmHelp)
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.verticalLayout = QtWidgets.QVBoxLayout()
        self.verticalLayout.setObjectName("verticalLayout")
        self.lblApp = QtWidgets.QLabel(frmHelp)
        font = QtGui.QFont()
        font.setPointSize(20)
        font.setBold(True)
        font.setWeight(75)
        self.lblApp.setFont(font)
        self.lblApp.setAlignment(QtCore.Qt.AlignCenter)
        self.lblApp.setObjectName("lblApp")
        self.verticalLayout.addWidget(self.lblApp)
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        spacerItem = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout.addItem(spacerItem)
        self.lblPixmap = QtWidgets.QLabel(frmHelp)
        self.lblPixmap.setMaximumSize(QtCore.QSize(68, 68))
        self.lblPixmap.setPixmap(QtGui.QPixmap(":/xulpymoney/books.png"))
        self.lblPixmap.setScaledContents(True)
        self.lblPixmap.setAlignment(QtCore.Qt.AlignCenter)
        self.lblPixmap.setObjectName("lblPixmap")
        self.horizontalLayout.addWidget(self.lblPixmap)
        spacerItem1 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout.addItem(spacerItem1)
        self.verticalLayout.addLayout(self.horizontalLayout)
        self.webEngineView = QtWebEngineWidgets.QWebEngineView(frmHelp)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.webEngineView.sizePolicy().hasHeightForWidth())
        self.webEngineView.setSizePolicy(sizePolicy)
        self.webEngineView.setUrl(QtCore.QUrl("https://github.com/turulomio/xulpymoney/wiki"))
        self.webEngineView.setObjectName("webEngineView")
        self.verticalLayout.addWidget(self.webEngineView)
        self.horizontalLayout_2.addLayout(self.verticalLayout)

        self.retranslateUi(frmHelp)
        QtCore.QMetaObject.connectSlotsByName(frmHelp)

    def retranslateUi(self, frmHelp):
        _translate = QtCore.QCoreApplication.translate
        frmHelp.setWindowTitle(_translate("frmHelp", "Xulpymoney help"))
        self.lblApp.setText(_translate("frmHelp", "Xulpymoney Help"))


from PyQt5 import QtWebEngineWidgets
import xulpymoney.images.xulpymoney_rc



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'xulpymoney/ui/wdgProductsComparation.ui'
#
# Created by: PyQt5 UI code generator 5.12.2
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_wdgProductsComparation(object):
    def setupUi(self, wdgProductsComparation):
        wdgProductsComparation.setObjectName("wdgProductsComparation")
        wdgProductsComparation.resize(955, 261)
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout(wdgProductsComparation)
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.verticalLayout = QtWidgets.QVBoxLayout()
        self.verticalLayout.setObjectName("verticalLayout")
        self.lbl = QtWidgets.QLabel(wdgProductsComparation)
        font = QtGui.QFont()
        font.setPointSize(14)
        font.setBold(True)
        font.setWeight(75)
        self.lbl.setFont(font)
        self.lbl.setAlignment(QtCore.Qt.AlignCenter)
        self.lbl.setObjectName("lbl")
        self.verticalLayout.addWidget(self.lbl)
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.verticalLayout_4 = QtWidgets.QVBoxLayout()
        self.verticalLayout_4.setObjectName("verticalLayout_4")
        self.selector1 = wdgProductSelector(wdgProductsComparation)
        self.selector1.setObjectName("selector1")
        self.verticalLayout_4.addWidget(self.selector1)
        self.selector2 = wdgProductSelector(wdgProductsComparation)
        self.selector2.setObjectName("selector2")
        self.verticalLayout_4.addWidget(self.selector2)
        self.horizontalLayout.addLayout(self.verticalLayout_4)
        self.line_3 = QtWidgets.QFrame(wdgProductsComparation)
        self.line_3.setFrameShape(QtWidgets.QFrame.VLine)
        self.line_3.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_3.setObjectName("line_3")
        self.horizontalLayout.addWidget(self.line_3)
        self.label_2 = QtWidgets.QLabel(wdgProductsComparation)
        self.label_2.setObjectName("label_2")
        self.horizontalLayout.addWidget(self.label_2)
        self.cmbCompareTypes = QtWidgets.QComboBox(wdgProductsComparation)
        self.cmbCompareTypes.setSizeAdjustPolicy(QtWidgets.QComboBox.AdjustToContents)
        self.cmbCompareTypes.setObjectName("cmbCompareTypes")
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(":/xulpymoney/eye.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.cmbCompareTypes.addItem(icon, "")
        icon1 = QtGui.QIcon()
        icon1.addPixmap(QtGui.QPixmap(":/xulpymoney/eye_red.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.cmbCompareTypes.addItem(icon1, "")
        self.cmbCompareTypes.addItem(icon, "")
        self.cmbCompareTypes.addItem(icon1, "")
        self.cmbCompareTypes.addItem(icon, "")
        self.cmbCompareTypes.addItem(icon1, "")
        self.horizontalLayout.addWidget(self.cmbCompareTypes)
        self.line = QtWidgets.QFrame(wdgProductsComparation)
        self.line.setFrameShape(QtWidgets.QFrame.VLine)
        self.line.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line.setObjectName("line")
        self.horizontalLayout.addWidget(self.line)
        self.label_7 = QtWidgets.QLabel(wdgProductsComparation)
        self.label_7.setObjectName("label_7")
        self.horizontalLayout.addWidget(self.label_7)
        self.deCompare = QtWidgets.QDateEdit(wdgProductsComparation)
        self.deCompare.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.deCompare.setCalendarPopup(True)
        self.deCompare.setObjectName("deCompare")
        self.horizontalLayout.addWidget(self.deCompare)
        self.line_2 = QtWidgets.QFrame(wdgProductsComparation)
        self.line_2.setFrameShape(QtWidgets.QFrame.VLine)
        self.line_2.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_2.setObjectName("line_2")
        self.horizontalLayout.addWidget(self.line_2)
        self.cmdComparationData = QtWidgets.QToolButton(wdgProductsComparation)
        self.cmdComparationData.setText("")
        icon2 = QtGui.QIcon()
        icon2.addPixmap(QtGui.QPixmap(":/xulpymoney/database.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.cmdComparationData.setIcon(icon2)
        self.cmdComparationData.setObjectName("cmdComparationData")
        self.horizontalLayout.addWidget(self.cmdComparationData)
        self.cmdComparation = QtWidgets.QPushButton(wdgProductsComparation)
        icon3 = QtGui.QIcon()
        icon3.addPixmap(QtGui.QPixmap(":/xulpymoney/compare.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.cmdComparation.setIcon(icon3)
        self.cmdComparation.setObjectName("cmdComparation")
        self.horizontalLayout.addWidget(self.cmdComparation)
        self.verticalLayout.addLayout(self.horizontalLayout)
        self.viewCompare = QtWidgets.QWidget(wdgProductsComparation)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.viewCompare.sizePolicy().hasHeightForWidth())
        self.viewCompare.setSizePolicy(sizePolicy)
        self.viewCompare.setObjectName("viewCompare")
        self.verticalLayout.addWidget(self.viewCompare)
        self.horizontalLayout_2.addLayout(self.verticalLayout)

        self.retranslateUi(wdgProductsComparation)
        QtCore.QMetaObject.connectSlotsByName(wdgProductsComparation)

    def retranslateUi(self, wdgProductsComparation):
        _translate = QtCore.QCoreApplication.translate
        wdgProductsComparation.setWindowTitle(_translate("wdgProductsComparation", "Form"))
        self.lbl.setText(_translate("wdgProductsComparation", "Products comparation"))
        self.label_2.setText(_translate("wdgProductsComparation", "Select a method to compare"))
        self.cmbCompareTypes.setItemText(0, _translate("wdgProductsComparation", "Not changed data"))
        self.cmbCompareTypes.setItemText(1, _translate("wdgProductsComparation", "Scattering product prices"))
        self.cmbCompareTypes.setItemText(2, _translate("wdgProductsComparation", "Controling percentage evolution"))
        self.cmbCompareTypes.setItemText(3, _translate("wdgProductsComparation", "Controlling percentage evolution. Leveraged reduced"))
        self.cmbCompareTypes.setItemText(4, _translate("wdgProductsComparation", "Controling inverse percentage evolution"))
        self.cmbCompareTypes.setItemText(5, _translate("wdgProductsComparation", "Controling inverse percentage evolultion. Leveraged reduced"))
        self.label_7.setText(_translate("wdgProductsComparation", "From date"))
        self.deCompare.setDisplayFormat(_translate("wdgProductsComparation", "yyyy-MM-dd"))
        self.cmdComparationData.setToolTip(_translate("wdgProductsComparation", "Shows comparation data"))
        self.cmdComparation.setText(_translate("wdgProductsComparation", "Compare"))


from xulpymoney.ui.wdgProductSelector import wdgProductSelector
import xulpymoney.images.xulpymoney_rc



from PyQt5.QtWidgets import QWidget, QHBoxLayout, QToolButton, QInputDialog, QLineEdit, QSizePolicy
from PyQt5.QtGui import QIcon, QPixmap
from xulpymoney.ui.myqlineedit import myQLineEdit
from decimal import Decimal

class wdgCurrencyConversion(QWidget):
    def __init__(self, parent):
        QWidget.__init__(self, parent)
        lay = QHBoxLayout(self)
        self.txt=myQLineEdit(self)       
        sizePolicy = QSizePolicy(QSizePolicy.Minimum, QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.txt.sizePolicy().hasHeightForWidth())
        self.txt.setSizePolicy(sizePolicy)
        self.txt.setReadOnly(True)
        self.cmd= QToolButton(self)             
        self.cmd.released.connect(self.on_cmd_released)
        icon = QIcon()
        icon.addPixmap(QPixmap(":/xulpymoney/add.png"), QIcon.Normal, QIcon.Off)
        self.cmd.setIcon(icon)     
        lay.addWidget(self.txt)
        lay.addWidget(self.cmd)

    def setConversion(self, mfrom, tcurrency, dt, factor=None):
        """Llena el texto con los datos de la conversión. Can be invoked several times
        Si se pasa el parametro factor, ya se calculan los datos, Se usa para modificaciones"""
        self.mem=mfrom.mem
        self.mfrom=mfrom
        self.tcurrency=tcurrency
        self.dt=dt
        if factor==None:
            self.factor=self.mfrom.conversionFactor(tcurrency, dt)
        else:
            self.factor=factor
        self.txt.setText(self.mfrom.convert_from_factor(tcurrency, self.factor).amount)
        self.txt.setToolTip(self.tr("Factor conversion from {} to {} at {} is {}. So {} are {}.".format(self.mfrom.currency.id, tcurrency.id, dt, self.factor,  self.mfrom, self.mfrom.convert_from_factor(tcurrency, self.factor))))

    def decimal(self):
        return self.txt.decimal()
 
    def on_cmd_released(self):
        if self.factor==None:
            input=QInputDialog.getText(self,  "Xulpymoney",  self.tr("Please introduce the relation between {} and {}. To help you I set value at {}.".format(self.mfrom.currency.id, self.tcurrency.id, self.dt)), QLineEdit.Normal, str(self.mfrom.conversionFactor(self.tcurrency, self.dt)))
        else:
            input=QInputDialog.getText(self,  "Xulpymoney",  self.tr("Please change relation between {} and {} if necessary".format(self.mfrom.currency.id, self.tcurrency.id)), QLineEdit.Normal, str(self.factor))
        if input[1]==True:
            try:
                self.setConversion(self.mfrom, self.tcurrency, self.dt, Decimal(input[0]))
            except:
                pass



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'xulpymoney/ui/wdgAPR.ui'
#
# Created by: PyQt5 UI code generator 5.12.2
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_wdgAPR(object):
    def setupUi(self, wdgAPR):
        wdgAPR.setObjectName("wdgAPR")
        wdgAPR.resize(1199, 447)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(wdgAPR.sizePolicy().hasHeightForWidth())
        wdgAPR.setSizePolicy(sizePolicy)
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(":/xulpymoney/history.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        wdgAPR.setWindowIcon(icon)
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout(wdgAPR)
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.verticalLayout = QtWidgets.QVBoxLayout()
        self.verticalLayout.setObjectName("verticalLayout")
        self.lbl = QtWidgets.QLabel(wdgAPR)
        font = QtGui.QFont()
        font.setPointSize(14)
        font.setBold(True)
        font.setWeight(75)
        self.lbl.setFont(font)
        self.lbl.setAlignment(QtCore.Qt.AlignCenter)
        self.lbl.setObjectName("lbl")
        self.verticalLayout.addWidget(self.lbl)
        self.horizontalLayout_4 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_4.setObjectName("horizontalLayout_4")
        spacerItem = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_4.addItem(spacerItem)
        self.wdgYear = wdgYear(wdgAPR)
        self.wdgYear.setObjectName("wdgYear")
        self.horizontalLayout_4.addWidget(self.wdgYear)
        spacerItem1 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_4.addItem(spacerItem1)
        self.verticalLayout.addLayout(self.horizontalLayout_4)
        self.tab = QtWidgets.QTabWidget(wdgAPR)
        self.tab.setObjectName("tab")
        self.tab_5 = QtWidgets.QWidget()
        self.tab_5.setObjectName("tab_5")
        self.horizontalLayout = QtWidgets.QHBoxLayout(self.tab_5)
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.table = myQTableWidget(self.tab_5)
        self.table.setEditTriggers(QtWidgets.QAbstractItemView.NoEditTriggers)
        self.table.setSelectionMode(QtWidgets.QAbstractItemView.SingleSelection)
        self.table.setObjectName("table")
        self.table.setColumnCount(10)
        self.table.setRowCount(0)
        item = QtWidgets.QTableWidgetItem()
        self.table.setHorizontalHeaderItem(0, item)
        item = QtWidgets.QTableWidgetItem()
        self.table.setHorizontalHeaderItem(1, item)
        item = QtWidgets.QTableWidgetItem()
        self.table.setHorizontalHeaderItem(2, item)
        item = QtWidgets.QTableWidgetItem()
        self.table.setHorizontalHeaderItem(3, item)
        item = QtWidgets.QTableWidgetItem()
        self.table.setHorizontalHeaderItem(4, item)
        item = QtWidgets.QTableWidgetItem()
        self.table.setHorizontalHeaderItem(5, item)
        item = QtWidgets.QTableWidgetItem()
        self.table.setHorizontalHeaderItem(6, item)
        item = QtWidgets.QTableWidgetItem()
        self.table.setHorizontalHeaderItem(7, item)
        item = QtWidgets.QTableWidgetItem()
        self.table.setHorizontalHeaderItem(8, item)
        item = QtWidgets.QTableWidgetItem()
        self.table.setHorizontalHeaderItem(9, item)
        self.table.verticalHeader().setVisible(False)
        self.horizontalLayout.addWidget(self.table)
        icon1 = QtGui.QIcon()
        icon1.addPixmap(QtGui.QPixmap(":/xulpymoney/document-edit.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.tab.addTab(self.tab_5, icon1, "")
        self.tab_2 = QtWidgets.QWidget()
        self.tab_2.setObjectName("tab_2")
        self.horizontalLayout_5 = QtWidgets.QHBoxLayout(self.tab_2)
        self.horizontalLayout_5.setObjectName("horizontalLayout_5")
        self.verticalLayout_2 = QtWidgets.QVBoxLayout()
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.tblReport = myQTableWidget(self.tab_2)
        self.tblReport.setObjectName("tblReport")
        self.tblReport.setColumnCount(10)
        self.tblReport.setRowCount(0)
        item = QtWidgets.QTableWidgetItem()
        self.tblReport.setHorizontalHeaderItem(0, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblReport.setHorizontalHeaderItem(1, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblReport.setHorizontalHeaderItem(2, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblReport.setHorizontalHeaderItem(3, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblReport.setHorizontalHeaderItem(4, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblReport.setHorizontalHeaderItem(5, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblReport.setHorizontalHeaderItem(6, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblReport.setHorizontalHeaderItem(7, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblReport.setHorizontalHeaderItem(8, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblReport.setHorizontalHeaderItem(9, item)
        self.tblReport.verticalHeader().setVisible(False)
        self.verticalLayout_2.addWidget(self.tblReport)
        self.lblReport = QtWidgets.QLabel(self.tab_2)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.lblReport.setFont(font)
        self.lblReport.setText("")
        self.lblReport.setAlignment(QtCore.Qt.AlignCenter)
        self.lblReport.setObjectName("lblReport")
        self.verticalLayout_2.addWidget(self.lblReport)
        self.horizontalLayout_5.addLayout(self.verticalLayout_2)
        icon2 = QtGui.QIcon()
        icon2.addPixmap(QtGui.QPixmap(":/xulpymoney/coins.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.tab.addTab(self.tab_2, icon2, "")
        self.verticalLayout.addWidget(self.tab)
        self.horizontalLayout_2.addLayout(self.verticalLayout)

        self.retranslateUi(wdgAPR)
        self.tab.setCurrentIndex(0)
        QtCore.QMetaObject.connectSlotsByName(wdgAPR)

    def retranslateUi(self, wdgAPR):
        _translate = QtCore.QCoreApplication.translate
        self.lbl.setText(_translate("wdgAPR", "Assets report"))
        item = self.table.horizontalHeaderItem(0)
        item.setText(_translate("wdgAPR", "Year"))
        item = self.table.horizontalHeaderItem(1)
        item.setText(_translate("wdgAPR", "Initial balance"))
        item = self.table.horizontalHeaderItem(2)
        item.setText(_translate("wdgAPR", "Final balance"))
        item = self.table.horizontalHeaderItem(3)
        item.setText(_translate("wdgAPR", "Difference"))
        item = self.table.horizontalHeaderItem(4)
        item.setText(_translate("wdgAPR", "Incomes"))
        item = self.table.horizontalHeaderItem(5)
        item.setText(_translate("wdgAPR", "Net gains"))
        item = self.table.horizontalHeaderItem(6)
        item.setText(_translate("wdgAPR", "Net dividends"))
        item = self.table.horizontalHeaderItem(7)
        item.setText(_translate("wdgAPR", "Expenses"))
        item = self.table.horizontalHeaderItem(8)
        item.setText(_translate("wdgAPR", "I+G+D-E"))
        item = self.table.horizontalHeaderItem(9)
        item.setText(_translate("wdgAPR", "% APR"))
        self.tab.setTabText(self.tab.indexOf(self.tab_5), _translate("wdgAPR", "Assets report"))
        item = self.tblReport.horizontalHeaderItem(0)
        item.setText(_translate("wdgAPR", "Year"))
        item = self.tblReport.horizontalHeaderItem(1)
        item.setText(_translate("wdgAPR", "Invested balance"))
        item = self.tblReport.horizontalHeaderItem(2)
        item.setText(_translate("wdgAPR", "Investment valoration"))
        item = self.tblReport.horizontalHeaderItem(3)
        item.setText(_translate("wdgAPR", "Diff"))
        item = self.tblReport.horizontalHeaderItem(4)
        item.setText(_translate("wdgAPR", "%"))
        item = self.tblReport.horizontalHeaderItem(6)
        item.setText(_translate("wdgAPR", "Net Gains + Dividends"))
        item = self.tblReport.horizontalHeaderItem(8)
        item.setText(_translate("wdgAPR", "Taxes"))
        item = self.tblReport.horizontalHeaderItem(9)
        item.setText(_translate("wdgAPR", "Comissions"))
        self.tab.setTabText(self.tab.indexOf(self.tab_2), _translate("wdgAPR", "Invested report"))


from xulpymoney.ui.myqtablewidget import myQTableWidget
from xulpymoney.ui.wdgYear import wdgYear
import xulpymoney.images.xulpymoney_rc



from xulpymoney.libxulpymoney import DPS
from PyQt5.QtWidgets import QDialog
from xulpymoney.ui.Ui_frmDPSAdd import Ui_frmDPSAdd

class frmDPSAdd(QDialog, Ui_frmDPSAdd):
    def __init__(self, mem,  product,   parent=None):
        """type="dps or "eps" """
        QDialog.__init__(self, parent)
        self.setupUi(self)
        self.mem=mem
        self.product=product
        self.dps=None
        self.lbl.setText(self.tr("New DPS"))

    def on_cmd_released(self):
        self.dps=DPS(self.mem, self.product).init__create(self.calendar.selectedDate().toPyDate(), self.txtGross.decimal())
        self.dps.save()
        self.mem.con.commit()      
        self.product.dps.arr.append(self.dps)
        self.accept()



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'xulpymoney/ui/frmProductReport.ui'
#
# Created by: PyQt5 UI code generator 5.12.2
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_frmProductReport(object):
    def setupUi(self, frmProductReport):
        frmProductReport.setObjectName("frmProductReport")
        frmProductReport.setWindowModality(QtCore.Qt.WindowModal)
        frmProductReport.resize(1052, 974)
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(":/xulpmoney/dinero.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        frmProductReport.setWindowIcon(icon)
        frmProductReport.setModal(True)
        self.horizontalLayout_22 = QtWidgets.QHBoxLayout(frmProductReport)
        self.horizontalLayout_22.setObjectName("horizontalLayout_22")
        self.verticalLayout = QtWidgets.QVBoxLayout()
        self.verticalLayout.setObjectName("verticalLayout")
        self.horizontalLayout_8 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_8.setObjectName("horizontalLayout_8")
        self.lblInvestment = QtWidgets.QLabel(frmProductReport)
        font = QtGui.QFont()
        font.setPointSize(12)
        self.lblInvestment.setFont(font)
        self.lblInvestment.setStyleSheet("color: rgb(0, 192, 0);")
        self.lblInvestment.setText("")
        self.lblInvestment.setAlignment(QtCore.Qt.AlignCenter)
        self.lblInvestment.setTextInteractionFlags(QtCore.Qt.LinksAccessibleByMouse|QtCore.Qt.TextSelectableByMouse)
        self.lblInvestment.setObjectName("lblInvestment")
        self.horizontalLayout_8.addWidget(self.lblInvestment)
        self.verticalLayout.addLayout(self.horizontalLayout_8)
        self.tab = QtWidgets.QTabWidget(frmProductReport)
        self.tab.setTabPosition(QtWidgets.QTabWidget.West)
        self.tab.setObjectName("tab")
        self.tabInformacion = QtWidgets.QWidget()
        self.tabInformacion.setObjectName("tabInformacion")
        self.verticalLayout_5 = QtWidgets.QVBoxLayout(self.tabInformacion)
        self.verticalLayout_5.setObjectName("verticalLayout_5")
        self.horizontalLayout_39 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_39.setObjectName("horizontalLayout_39")
        self.scrollArea = QtWidgets.QScrollArea(self.tabInformacion)
        self.scrollArea.setHorizontalScrollBarPolicy(QtCore.Qt.ScrollBarAlwaysOff)
        self.scrollArea.setWidgetResizable(True)
        self.scrollArea.setObjectName("scrollArea")
        self.scrollAreaWidgetContents = QtWidgets.QWidget()
        self.scrollAreaWidgetContents.setGeometry(QtCore.QRect(0, 0, 983, 901))
        self.scrollAreaWidgetContents.setObjectName("scrollAreaWidgetContents")
        self.horizontalLayout_31 = QtWidgets.QHBoxLayout(self.scrollAreaWidgetContents)
        self.horizontalLayout_31.setObjectName("horizontalLayout_31")
        self.grpInformation = QtWidgets.QGroupBox(self.scrollAreaWidgetContents)
        self.grpInformation.setObjectName("grpInformation")
        self.horizontalLayout_26 = QtWidgets.QHBoxLayout(self.grpInformation)
        self.horizontalLayout_26.setObjectName("horizontalLayout_26")
        self.verticalLayout_2 = QtWidgets.QVBoxLayout()
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.horizontalLayout_10 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_10.setObjectName("horizontalLayout_10")
        self.label = QtWidgets.QLabel(self.grpInformation)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label.sizePolicy().hasHeightForWidth())
        self.label.setSizePolicy(sizePolicy)
        self.label.setMinimumSize(QtCore.QSize(230, 0))
        self.label.setObjectName("label")
        self.horizontalLayout_10.addWidget(self.label)
        self.txtName = QtWidgets.QLineEdit(self.grpInformation)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.txtName.sizePolicy().hasHeightForWidth())
        self.txtName.setSizePolicy(sizePolicy)
        self.txtName.setMinimumSize(QtCore.QSize(330, 0))
        self.txtName.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.txtName.setObjectName("txtName")
        self.horizontalLayout_10.addWidget(self.txtName)
        self.verticalLayout_2.addLayout(self.horizontalLayout_10)
        self.horizontalLayout_21 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_21.setObjectName("horizontalLayout_21")
        self.label_10 = QtWidgets.QLabel(self.grpInformation)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_10.sizePolicy().hasHeightForWidth())
        self.label_10.setSizePolicy(sizePolicy)
        self.label_10.setMinimumSize(QtCore.QSize(230, 0))
        self.label_10.setObjectName("label_10")
        self.horizontalLayout_21.addWidget(self.label_10)
        self.txtISIN = QtWidgets.QLineEdit(self.grpInformation)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.txtISIN.sizePolicy().hasHeightForWidth())
        self.txtISIN.setSizePolicy(sizePolicy)
        self.txtISIN.setMinimumSize(QtCore.QSize(230, 0))
        self.txtISIN.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.txtISIN.setObjectName("txtISIN")
        self.horizontalLayout_21.addWidget(self.txtISIN)
        self.verticalLayout_2.addLayout(self.horizontalLayout_21)
        self.horizontalLayout_15 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_15.setObjectName("horizontalLayout_15")
        self.label_9 = QtWidgets.QLabel(self.grpInformation)
        self.label_9.setObjectName("label_9")
        self.horizontalLayout_15.addWidget(self.label_9)
        self.cmbCurrency = QtWidgets.QComboBox(self.grpInformation)
        self.cmbCurrency.setObjectName("cmbCurrency")
        self.horizontalLayout_15.addWidget(self.cmbCurrency)
        self.verticalLayout_2.addLayout(self.horizontalLayout_15)
        self.horizontalLayout_23 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_23.setObjectName("horizontalLayout_23")
        self.label_12 = QtWidgets.QLabel(self.grpInformation)
        self.label_12.setObjectName("label_12")
        self.horizontalLayout_23.addWidget(self.label_12)
        self.cmbTipo = QtWidgets.QComboBox(self.grpInformation)
        self.cmbTipo.setObjectName("cmbTipo")
        self.horizontalLayout_23.addWidget(self.cmbTipo)
        self.verticalLayout_2.addLayout(self.horizontalLayout_23)
        self.horizontalLayout_30 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_30.setObjectName("horizontalLayout_30")
        self.label_16 = QtWidgets.QLabel(self.grpInformation)
        self.label_16.setObjectName("label_16")
        self.horizontalLayout_30.addWidget(self.label_16)
        self.cmbBolsa = QtWidgets.QComboBox(self.grpInformation)
        self.cmbBolsa.setObjectName("cmbBolsa")
        self.horizontalLayout_30.addWidget(self.cmbBolsa)
        self.verticalLayout_2.addLayout(self.horizontalLayout_30)
        self.horizontalLayout_24 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_24.setObjectName("horizontalLayout_24")
        self.label_13 = QtWidgets.QLabel(self.grpInformation)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_13.sizePolicy().hasHeightForWidth())
        self.label_13.setSizePolicy(sizePolicy)
        self.label_13.setMinimumSize(QtCore.QSize(230, 0))
        self.label_13.setObjectName("label_13")
        self.horizontalLayout_24.addWidget(self.label_13)
        self.cmbAgrupations = QtWidgets.QComboBox(self.grpInformation)
        self.cmbAgrupations.setObjectName("cmbAgrupations")
        self.horizontalLayout_24.addWidget(self.cmbAgrupations)
        self.cmdAgrupations = QtWidgets.QToolButton(self.grpInformation)
        icon1 = QtGui.QIcon()
        icon1.addPixmap(QtGui.QPixmap(":/xulpymoney/search.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.cmdAgrupations.setIcon(icon1)
        self.cmdAgrupations.setObjectName("cmdAgrupations")
        self.horizontalLayout_24.addWidget(self.cmdAgrupations)
        self.verticalLayout_2.addLayout(self.horizontalLayout_24)
        self.horizontalLayout_14 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_14.setObjectName("horizontalLayout_14")
        self.label_3 = QtWidgets.QLabel(self.grpInformation)
        self.label_3.setObjectName("label_3")
        self.horizontalLayout_14.addWidget(self.label_3)
        self.txtWeb = QtWidgets.QLineEdit(self.grpInformation)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.txtWeb.sizePolicy().hasHeightForWidth())
        self.txtWeb.setSizePolicy(sizePolicy)
        self.txtWeb.setMinimumSize(QtCore.QSize(230, 0))
        self.txtWeb.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.txtWeb.setObjectName("txtWeb")
        self.horizontalLayout_14.addWidget(self.txtWeb)
        self.verticalLayout_2.addLayout(self.horizontalLayout_14)
        self.horizontalLayout_17 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_17.setObjectName("horizontalLayout_17")
        self.label_4 = QtWidgets.QLabel(self.grpInformation)
        self.label_4.setObjectName("label_4")
        self.horizontalLayout_17.addWidget(self.label_4)
        self.txtAddress = QtWidgets.QLineEdit(self.grpInformation)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.txtAddress.sizePolicy().hasHeightForWidth())
        self.txtAddress.setSizePolicy(sizePolicy)
        self.txtAddress.setMinimumSize(QtCore.QSize(230, 0))
        self.txtAddress.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.txtAddress.setObjectName("txtAddress")
        self.horizontalLayout_17.addWidget(self.txtAddress)
        self.verticalLayout_2.addLayout(self.horizontalLayout_17)
        self.horizontalLayout_27 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_27.setObjectName("horizontalLayout_27")
        self.lblMail = QtWidgets.QLabel(self.grpInformation)
        self.lblMail.setObjectName("lblMail")
        self.horizontalLayout_27.addWidget(self.lblMail)
        self.txtMail = QtWidgets.QLineEdit(self.grpInformation)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.txtMail.sizePolicy().hasHeightForWidth())
        self.txtMail.setSizePolicy(sizePolicy)
        self.txtMail.setMinimumSize(QtCore.QSize(230, 0))
        self.txtMail.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.txtMail.setObjectName("txtMail")
        self.horizontalLayout_27.addWidget(self.txtMail)
        self.verticalLayout_2.addLayout(self.horizontalLayout_27)
        self.horizontalLayout_28 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_28.setObjectName("horizontalLayout_28")
        self.label_14 = QtWidgets.QLabel(self.grpInformation)
        self.label_14.setObjectName("label_14")
        self.horizontalLayout_28.addWidget(self.label_14)
        self.txtTPC = QtWidgets.QLineEdit(self.grpInformation)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.txtTPC.sizePolicy().hasHeightForWidth())
        self.txtTPC.setSizePolicy(sizePolicy)
        self.txtTPC.setMinimumSize(QtCore.QSize(230, 0))
        self.txtTPC.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.txtTPC.setObjectName("txtTPC")
        self.horizontalLayout_28.addWidget(self.txtTPC)
        self.verticalLayout_2.addLayout(self.horizontalLayout_28)
        self.horizontalLayout_38 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_38.setObjectName("horizontalLayout_38")
        self.label_22 = QtWidgets.QLabel(self.grpInformation)
        self.label_22.setObjectName("label_22")
        self.horizontalLayout_38.addWidget(self.label_22)
        self.cmbPCI = QtWidgets.QComboBox(self.grpInformation)
        self.cmbPCI.setObjectName("cmbPCI")
        self.horizontalLayout_38.addWidget(self.cmbPCI)
        self.verticalLayout_2.addLayout(self.horizontalLayout_38)
        self.horizontalLayout_18 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_18.setObjectName("horizontalLayout_18")
        self.label_5 = QtWidgets.QLabel(self.grpInformation)
        self.label_5.setObjectName("label_5")
        self.horizontalLayout_18.addWidget(self.label_5)
        self.txtPhone = QtWidgets.QLineEdit(self.grpInformation)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.txtPhone.sizePolicy().hasHeightForWidth())
        self.txtPhone.setSizePolicy(sizePolicy)
        self.txtPhone.setMinimumSize(QtCore.QSize(230, 0))
        self.txtPhone.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.txtPhone.setObjectName("txtPhone")
        self.horizontalLayout_18.addWidget(self.txtPhone)
        self.verticalLayout_2.addLayout(self.horizontalLayout_18)
        self.horizontalLayout_29 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_29.setObjectName("horizontalLayout_29")
        self.label_15 = QtWidgets.QLabel(self.grpInformation)
        self.label_15.setObjectName("label_15")
        self.horizontalLayout_29.addWidget(self.label_15)
        self.cmbApalancado = QtWidgets.QComboBox(self.grpInformation)
        self.cmbApalancado.setObjectName("cmbApalancado")
        self.horizontalLayout_29.addWidget(self.cmbApalancado)
        self.verticalLayout_2.addLayout(self.horizontalLayout_29)
        self.horizontalLayout_42 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_42.setObjectName("horizontalLayout_42")
        self.label_11 = QtWidgets.QLabel(self.grpInformation)
        self.label_11.setMinimumSize(QtCore.QSize(280, 0))
        self.label_11.setObjectName("label_11")
        self.horizontalLayout_42.addWidget(self.label_11)
        self.tblTickers = QtWidgets.QTableWidget(self.grpInformation)
        self.tblTickers.setMinimumSize(QtCore.QSize(230, 0))
        self.tblTickers.setAlternatingRowColors(True)
        self.tblTickers.setSelectionMode(QtWidgets.QAbstractItemView.SingleSelection)
        self.tblTickers.setObjectName("tblTickers")
        self.tblTickers.setColumnCount(1)
        self.tblTickers.setRowCount(4)
        item = QtWidgets.QTableWidgetItem()
        self.tblTickers.setVerticalHeaderItem(0, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblTickers.setVerticalHeaderItem(1, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblTickers.setVerticalHeaderItem(2, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblTickers.setVerticalHeaderItem(3, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblTickers.setHorizontalHeaderItem(0, item)
        item = QtWidgets.QTableWidgetItem()
        icon2 = QtGui.QIcon()
        icon2.addPixmap(QtGui.QPixmap(":/xulpymoney/eye_red.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        item.setIcon(icon2)
        self.tblTickers.setItem(0, 0, item)
        item = QtWidgets.QTableWidgetItem()
        item.setIcon(icon2)
        self.tblTickers.setItem(1, 0, item)
        item = QtWidgets.QTableWidgetItem()
        item.setIcon(icon2)
        self.tblTickers.setItem(2, 0, item)
        item = QtWidgets.QTableWidgetItem()
        item.setIcon(icon2)
        self.tblTickers.setItem(3, 0, item)
        self.tblTickers.horizontalHeader().setStretchLastSection(True)
        self.tblTickers.verticalHeader().setVisible(True)
        self.horizontalLayout_42.addWidget(self.tblTickers)
        self.verticalLayout_2.addLayout(self.horizontalLayout_42)
        self.horizontalLayout_36 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_36.setObjectName("horizontalLayout_36")
        self.label_21 = QtWidgets.QLabel(self.grpInformation)
        self.label_21.setObjectName("label_21")
        self.horizontalLayout_36.addWidget(self.label_21)
        self.txtComentario = QtWidgets.QLineEdit(self.grpInformation)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.txtComentario.sizePolicy().hasHeightForWidth())
        self.txtComentario.setSizePolicy(sizePolicy)
        self.txtComentario.setMinimumSize(QtCore.QSize(230, 0))
        self.txtComentario.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.txtComentario.setObjectName("txtComentario")
        self.horizontalLayout_36.addWidget(self.txtComentario)
        self.verticalLayout_2.addLayout(self.horizontalLayout_36)
        self.chkHL = QtWidgets.QCheckBox(self.grpInformation)
        self.chkHL.setObjectName("chkHL")
        self.verticalLayout_2.addWidget(self.chkHL)
        self.horizontalLayout_33 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_33.setObjectName("horizontalLayout_33")
        self.chkObsolete = QtWidgets.QCheckBox(self.grpInformation)
        self.chkObsolete.setObjectName("chkObsolete")
        self.horizontalLayout_33.addWidget(self.chkObsolete)
        self.verticalLayout_2.addLayout(self.horizontalLayout_33)
        self.lblAutoupdate = QtWidgets.QLabel(self.grpInformation)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.lblAutoupdate.setFont(font)
        self.lblAutoupdate.setText("")
        self.lblAutoupdate.setObjectName("lblAutoupdate")
        self.verticalLayout_2.addWidget(self.lblAutoupdate)
        self.cmdSave = QtWidgets.QPushButton(self.grpInformation)
        icon3 = QtGui.QIcon()
        icon3.addPixmap(QtGui.QPixmap(":/xulpymoney/save.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.cmdSave.setIcon(icon3)
        self.cmdSave.setObjectName("cmdSave")
        self.verticalLayout_2.addWidget(self.cmdSave)
        self.horizontalLayout_26.addLayout(self.verticalLayout_2)
        self.horizontalLayout_31.addWidget(self.grpInformation)
        self.scrollArea.setWidget(self.scrollAreaWidgetContents)
        self.horizontalLayout_39.addWidget(self.scrollArea)
        self.verticalLayout_5.addLayout(self.horizontalLayout_39)
        self.tab.addTab(self.tabInformacion, "")
        self.tabGraficos = QtWidgets.QWidget()
        self.tabGraficos.setObjectName("tabGraficos")
        self.horizontalLayout_6 = QtWidgets.QHBoxLayout(self.tabGraficos)
        self.horizontalLayout_6.setObjectName("horizontalLayout_6")
        self.tabGraphics = QtWidgets.QTabWidget(self.tabGraficos)
        self.tabGraphics.setObjectName("tabGraphics")
        self.tabGraphicsIntraday = QtWidgets.QWidget()
        self.tabGraphicsIntraday.setObjectName("tabGraphicsIntraday")
        self.horizontalLayout = QtWidgets.QHBoxLayout(self.tabGraphicsIntraday)
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.splitter = QtWidgets.QSplitter(self.tabGraphicsIntraday)
        self.splitter.setOrientation(QtCore.Qt.Horizontal)
        self.splitter.setObjectName("splitter")
        self.groupBox_3 = QtWidgets.QGroupBox(self.splitter)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupBox_3.sizePolicy().hasHeightForWidth())
        self.groupBox_3.setSizePolicy(sizePolicy)
        self.groupBox_3.setMaximumSize(QtCore.QSize(400, 16777215))
        self.groupBox_3.setObjectName("groupBox_3")
        self.verticalLayout_6 = QtWidgets.QVBoxLayout(self.groupBox_3)
        self.verticalLayout_6.setObjectName("verticalLayout_6")
        self.verticalLayout_3 = QtWidgets.QVBoxLayout()
        self.verticalLayout_3.setObjectName("verticalLayout_3")
        self.horizontalLayout_7 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_7.setObjectName("horizontalLayout_7")
        spacerItem = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_7.addItem(spacerItem)
        self.calendar = QtWidgets.QCalendarWidget(self.groupBox_3)
        self.calendar.setMaximumSize(QtCore.QSize(300, 200))
        self.calendar.setFirstDayOfWeek(QtCore.Qt.Monday)
        self.calendar.setHorizontalHeaderFormat(QtWidgets.QCalendarWidget.SingleLetterDayNames)
        self.calendar.setVerticalHeaderFormat(QtWidgets.QCalendarWidget.NoVerticalHeader)
        self.calendar.setObjectName("calendar")
        self.horizontalLayout_7.addWidget(self.calendar)
        spacerItem1 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_7.addItem(spacerItem1)
        self.verticalLayout_3.addLayout(self.horizontalLayout_7)
        self.tblIntradia = myQTableWidget(self.groupBox_3)
        self.tblIntradia.setContextMenuPolicy(QtCore.Qt.CustomContextMenu)
        self.tblIntradia.setAlternatingRowColors(True)
        self.tblIntradia.setSelectionBehavior(QtWidgets.QAbstractItemView.SelectRows)
        self.tblIntradia.setObjectName("tblIntradia")
        self.tblIntradia.setColumnCount(0)
        self.tblIntradia.setRowCount(0)
        self.tblIntradia.verticalHeader().setVisible(False)
        self.verticalLayout_3.addWidget(self.tblIntradia)
        self.lblIntradayVariance = QtWidgets.QLabel(self.groupBox_3)
        self.lblIntradayVariance.setText("")
        self.lblIntradayVariance.setObjectName("lblIntradayVariance")
        self.verticalLayout_3.addWidget(self.lblIntradayVariance)
        self.verticalLayout_6.addLayout(self.verticalLayout_3)
        self.grpGraphIntraday = QtWidgets.QGroupBox(self.splitter)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Maximum, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.grpGraphIntraday.sizePolicy().hasHeightForWidth())
        self.grpGraphIntraday.setSizePolicy(sizePolicy)
        self.grpGraphIntraday.setObjectName("grpGraphIntraday")
        self.horizontalLayout_11 = QtWidgets.QHBoxLayout(self.grpGraphIntraday)
        self.horizontalLayout_11.setObjectName("horizontalLayout_11")
        self.layIntraday = QtWidgets.QVBoxLayout()
        self.layIntraday.setObjectName("layIntraday")
        self.horizontalLayout_11.addLayout(self.layIntraday)
        self.horizontalLayout.addWidget(self.splitter)
        self.tabGraphics.addTab(self.tabGraphicsIntraday, "")
        self.tabGraphicsHistorical = QtWidgets.QWidget()
        self.tabGraphicsHistorical.setObjectName("tabGraphicsHistorical")
        self.horizontalLayout_34 = QtWidgets.QHBoxLayout(self.tabGraphicsHistorical)
        self.horizontalLayout_34.setObjectName("horizontalLayout_34")
        self.groupBox_2 = QtWidgets.QGroupBox(self.tabGraphicsHistorical)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupBox_2.sizePolicy().hasHeightForWidth())
        self.groupBox_2.setSizePolicy(sizePolicy)
        self.groupBox_2.setObjectName("groupBox_2")
        self.verticalLayout_10 = QtWidgets.QVBoxLayout(self.groupBox_2)
        self.verticalLayout_10.setObjectName("verticalLayout_10")
        self.layHistorical = QtWidgets.QVBoxLayout()
        self.layHistorical.setObjectName("layHistorical")
        self.verticalLayout_10.addLayout(self.layHistorical)
        self.horizontalLayout_34.addWidget(self.groupBox_2)
        self.tabGraphics.addTab(self.tabGraphicsHistorical, "")
        self.horizontalLayout_6.addWidget(self.tabGraphics)
        icon4 = QtGui.QIcon()
        icon4.addPixmap(QtGui.QPixmap(":/xulpymoney/pie.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.tab.addTab(self.tabGraficos, icon4, "")
        self.tabQuotes = QtWidgets.QWidget()
        self.tabQuotes.setObjectName("tabQuotes")
        self.horizontalLayout_37 = QtWidgets.QHBoxLayout(self.tabQuotes)
        self.horizontalLayout_37.setObjectName("horizontalLayout_37")
        self.verticalLayout_7 = QtWidgets.QVBoxLayout()
        self.verticalLayout_7.setObjectName("verticalLayout_7")
        self.grpHistoricos = QtWidgets.QGroupBox(self.tabQuotes)
        self.grpHistoricos.setObjectName("grpHistoricos")
        self.horizontalLayout_19 = QtWidgets.QHBoxLayout(self.grpHistoricos)
        self.horizontalLayout_19.setObjectName("horizontalLayout_19")
        self.tblTPC = myQTableWidget(self.grpHistoricos)
        self.tblTPC.setObjectName("tblTPC")
        self.tblTPC.setColumnCount(5)
        self.tblTPC.setRowCount(10)
        item = QtWidgets.QTableWidgetItem()
        self.tblTPC.setVerticalHeaderItem(0, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblTPC.setVerticalHeaderItem(1, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblTPC.setVerticalHeaderItem(2, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblTPC.setVerticalHeaderItem(3, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblTPC.setVerticalHeaderItem(4, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblTPC.setVerticalHeaderItem(5, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblTPC.setVerticalHeaderItem(6, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblTPC.setVerticalHeaderItem(7, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblTPC.setVerticalHeaderItem(8, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblTPC.setVerticalHeaderItem(9, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblTPC.setHorizontalHeaderItem(0, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblTPC.setHorizontalHeaderItem(1, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblTPC.setHorizontalHeaderItem(2, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblTPC.setHorizontalHeaderItem(3, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblTPC.setHorizontalHeaderItem(4, item)
        item = QtWidgets.QTableWidgetItem()
        font = QtGui.QFont()
        font.setStrikeOut(False)
        item.setFont(font)
        self.tblTPC.setItem(0, 0, item)
        item = QtWidgets.QTableWidgetItem()
        brush = QtGui.QBrush(QtGui.QColor(0, 0, 0))
        brush.setStyle(QtCore.Qt.BDiagPattern)
        item.setBackground(brush)
        self.tblTPC.setItem(0, 2, item)
        item = QtWidgets.QTableWidgetItem()
        brush = QtGui.QBrush(QtGui.QColor(0, 0, 0))
        brush.setStyle(QtCore.Qt.BDiagPattern)
        item.setBackground(brush)
        self.tblTPC.setItem(0, 3, item)
        item = QtWidgets.QTableWidgetItem()
        brush = QtGui.QBrush(QtGui.QColor(0, 0, 0))
        brush.setStyle(QtCore.Qt.BDiagPattern)
        item.setBackground(brush)
        self.tblTPC.setItem(0, 4, item)
        self.horizontalLayout_19.addWidget(self.tblTPC)
        self.verticalLayout_7.addWidget(self.grpHistoricos)
        self.horizontalLayout_16 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_16.setObjectName("horizontalLayout_16")
        self.cmdPurge = QtWidgets.QPushButton(self.tabQuotes)
        icon5 = QtGui.QIcon()
        icon5.addPixmap(QtGui.QPixmap(":/xulpymoney/button_cancel.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.cmdPurge.setIcon(icon5)
        self.cmdPurge.setObjectName("cmdPurge")
        self.horizontalLayout_16.addWidget(self.cmdPurge)
        self.cmdSplitManual = QtWidgets.QPushButton(self.tabQuotes)
        icon6 = QtGui.QIcon()
        icon6.addPixmap(QtGui.QPixmap(":/xulpymoney/history2.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.cmdSplitManual.setIcon(icon6)
        self.cmdSplitManual.setObjectName("cmdSplitManual")
        self.horizontalLayout_16.addWidget(self.cmdSplitManual)
        self.verticalLayout_7.addLayout(self.horizontalLayout_16)
        self.groupBox_9 = QtWidgets.QGroupBox(self.tabQuotes)
        self.groupBox_9.setObjectName("groupBox_9")
        self.horizontalLayout_5 = QtWidgets.QHBoxLayout(self.groupBox_9)
        self.horizontalLayout_5.setObjectName("horizontalLayout_5")
        self.tabHistorical = QtWidgets.QTabWidget(self.groupBox_9)
        self.tabHistorical.setElideMode(QtCore.Qt.ElideMiddle)
        self.tabHistorical.setObjectName("tabHistorical")
        self.tab_5 = QtWidgets.QWidget()
        self.tab_5.setObjectName("tab_5")
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout(self.tab_5)
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.verticalLayout_12 = QtWidgets.QVBoxLayout()
        self.verticalLayout_12.setObjectName("verticalLayout_12")
        self.tblDaily = myQTableWidget(self.tab_5)
        self.tblDaily.setContextMenuPolicy(QtCore.Qt.CustomContextMenu)
        self.tblDaily.setAlternatingRowColors(True)
        self.tblDaily.setSelectionBehavior(QtWidgets.QAbstractItemView.SelectRows)
        self.tblDaily.setObjectName("tblDaily")
        self.tblDaily.setColumnCount(6)
        self.tblDaily.setRowCount(0)
        item = QtWidgets.QTableWidgetItem()
        self.tblDaily.setHorizontalHeaderItem(0, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblDaily.setHorizontalHeaderItem(1, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblDaily.setHorizontalHeaderItem(2, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblDaily.setHorizontalHeaderItem(3, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblDaily.setHorizontalHeaderItem(4, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblDaily.setHorizontalHeaderItem(5, item)
        self.tblDaily.verticalHeader().setVisible(False)
        self.verticalLayout_12.addWidget(self.tblDaily)
        self.label_6 = QtWidgets.QLabel(self.tab_5)
        self.label_6.setObjectName("label_6")
        self.verticalLayout_12.addWidget(self.label_6)
        self.horizontalLayout_3.addLayout(self.verticalLayout_12)
        self.tabHistorical.addTab(self.tab_5, "")
        self.tab_14 = QtWidgets.QWidget()
        self.tab_14.setObjectName("tab_14")
        self.horizontalLayout_32 = QtWidgets.QHBoxLayout(self.tab_14)
        self.horizontalLayout_32.setObjectName("horizontalLayout_32")
        self.verticalLayout_4 = QtWidgets.QVBoxLayout()
        self.verticalLayout_4.setObjectName("verticalLayout_4")
        self.tblWeekly = myQTableWidget(self.tab_14)
        self.tblWeekly.setContextMenuPolicy(QtCore.Qt.CustomContextMenu)
        self.tblWeekly.setAlternatingRowColors(True)
        self.tblWeekly.setSelectionBehavior(QtWidgets.QAbstractItemView.SelectRows)
        self.tblWeekly.setObjectName("tblWeekly")
        self.tblWeekly.setColumnCount(6)
        self.tblWeekly.setRowCount(0)
        item = QtWidgets.QTableWidgetItem()
        self.tblWeekly.setHorizontalHeaderItem(0, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblWeekly.setHorizontalHeaderItem(1, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblWeekly.setHorizontalHeaderItem(2, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblWeekly.setHorizontalHeaderItem(3, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblWeekly.setHorizontalHeaderItem(4, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblWeekly.setHorizontalHeaderItem(5, item)
        self.tblWeekly.verticalHeader().setVisible(False)
        self.verticalLayout_4.addWidget(self.tblWeekly)
        self.label_8 = QtWidgets.QLabel(self.tab_14)
        self.label_8.setObjectName("label_8")
        self.verticalLayout_4.addWidget(self.label_8)
        self.horizontalLayout_32.addLayout(self.verticalLayout_4)
        self.tabHistorical.addTab(self.tab_14, "")
        self.tab_3 = QtWidgets.QWidget()
        self.tab_3.setObjectName("tab_3")
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout(self.tab_3)
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.verticalLayout_13 = QtWidgets.QVBoxLayout()
        self.verticalLayout_13.setObjectName("verticalLayout_13")
        self.tblMonthly = myQTableWidget(self.tab_3)
        self.tblMonthly.setContextMenuPolicy(QtCore.Qt.CustomContextMenu)
        self.tblMonthly.setAlternatingRowColors(True)
        self.tblMonthly.setSelectionBehavior(QtWidgets.QAbstractItemView.SelectRows)
        self.tblMonthly.setObjectName("tblMonthly")
        self.tblMonthly.setColumnCount(6)
        self.tblMonthly.setRowCount(0)
        item = QtWidgets.QTableWidgetItem()
        self.tblMonthly.setHorizontalHeaderItem(0, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblMonthly.setHorizontalHeaderItem(1, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblMonthly.setHorizontalHeaderItem(2, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblMonthly.setHorizontalHeaderItem(3, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblMonthly.setHorizontalHeaderItem(4, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblMonthly.setHorizontalHeaderItem(5, item)
        self.tblMonthly.verticalHeader().setVisible(False)
        self.verticalLayout_13.addWidget(self.tblMonthly)
        self.label_17 = QtWidgets.QLabel(self.tab_3)
        self.label_17.setObjectName("label_17")
        self.verticalLayout_13.addWidget(self.label_17)
        self.horizontalLayout_2.addLayout(self.verticalLayout_13)
        self.tabHistorical.addTab(self.tab_3, "")
        self.tab_13 = QtWidgets.QWidget()
        self.tab_13.setObjectName("tab_13")
        self.horizontalLayout_4 = QtWidgets.QHBoxLayout(self.tab_13)
        self.horizontalLayout_4.setObjectName("horizontalLayout_4")
        self.verticalLayout_14 = QtWidgets.QVBoxLayout()
        self.verticalLayout_14.setObjectName("verticalLayout_14")
        self.tblYearly = myQTableWidget(self.tab_13)
        self.tblYearly.setContextMenuPolicy(QtCore.Qt.CustomContextMenu)
        self.tblYearly.setAlternatingRowColors(True)
        self.tblYearly.setSelectionBehavior(QtWidgets.QAbstractItemView.SelectRows)
        self.tblYearly.setObjectName("tblYearly")
        self.tblYearly.setColumnCount(6)
        self.tblYearly.setRowCount(0)
        item = QtWidgets.QTableWidgetItem()
        self.tblYearly.setHorizontalHeaderItem(0, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblYearly.setHorizontalHeaderItem(1, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblYearly.setHorizontalHeaderItem(2, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblYearly.setHorizontalHeaderItem(3, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblYearly.setHorizontalHeaderItem(4, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblYearly.setHorizontalHeaderItem(5, item)
        self.tblYearly.verticalHeader().setVisible(False)
        self.verticalLayout_14.addWidget(self.tblYearly)
        self.label_18 = QtWidgets.QLabel(self.tab_13)
        self.label_18.setObjectName("label_18")
        self.verticalLayout_14.addWidget(self.label_18)
        self.horizontalLayout_4.addLayout(self.verticalLayout_14)
        self.tabHistorical.addTab(self.tab_13, "")
        self.tab_6 = QtWidgets.QWidget()
        self.tab_6.setObjectName("tab_6")
        self.horizontalLayout_9 = QtWidgets.QHBoxLayout(self.tab_6)
        self.horizontalLayout_9.setObjectName("horizontalLayout_9")
        self.verticalLayout_15 = QtWidgets.QVBoxLayout()
        self.verticalLayout_15.setObjectName("verticalLayout_15")
        self.tblMensuales = myQTableWidget(self.tab_6)
        self.tblMensuales.setObjectName("tblMensuales")
        self.tblMensuales.setColumnCount(14)
        self.tblMensuales.setRowCount(0)
        item = QtWidgets.QTableWidgetItem()
        self.tblMensuales.setHorizontalHeaderItem(0, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblMensuales.setHorizontalHeaderItem(1, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblMensuales.setHorizontalHeaderItem(2, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblMensuales.setHorizontalHeaderItem(3, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblMensuales.setHorizontalHeaderItem(4, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblMensuales.setHorizontalHeaderItem(5, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblMensuales.setHorizontalHeaderItem(6, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblMensuales.setHorizontalHeaderItem(7, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblMensuales.setHorizontalHeaderItem(8, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblMensuales.setHorizontalHeaderItem(9, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblMensuales.setHorizontalHeaderItem(10, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblMensuales.setHorizontalHeaderItem(11, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblMensuales.setHorizontalHeaderItem(12, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblMensuales.setHorizontalHeaderItem(13, item)
        self.tblMensuales.verticalHeader().setVisible(False)
        self.verticalLayout_15.addWidget(self.tblMensuales)
        self.label_19 = QtWidgets.QLabel(self.tab_6)
        self.label_19.setObjectName("label_19")
        self.verticalLayout_15.addWidget(self.label_19)
        self.horizontalLayout_9.addLayout(self.verticalLayout_15)
        icon7 = QtGui.QIcon()
        icon7.addPixmap(QtGui.QPixmap(":/xulpymoney/tools-wizard.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.tabHistorical.addTab(self.tab_6, icon7, "")
        self.tabSplits = QtWidgets.QWidget()
        self.tabSplits.setObjectName("tabSplits")
        self.horizontalLayout_45 = QtWidgets.QHBoxLayout(self.tabSplits)
        self.horizontalLayout_45.setObjectName("horizontalLayout_45")
        self.tblSplits = myQTableWidget(self.tabSplits)
        self.tblSplits.setContextMenuPolicy(QtCore.Qt.CustomContextMenu)
        self.tblSplits.setEditTriggers(QtWidgets.QAbstractItemView.NoEditTriggers)
        self.tblSplits.setAlternatingRowColors(True)
        self.tblSplits.setSelectionMode(QtWidgets.QAbstractItemView.SingleSelection)
        self.tblSplits.setSelectionBehavior(QtWidgets.QAbstractItemView.SelectRows)
        self.tblSplits.setObjectName("tblSplits")
        self.tblSplits.setColumnCount(0)
        self.tblSplits.setRowCount(0)
        self.tblSplits.verticalHeader().setVisible(False)
        self.horizontalLayout_45.addWidget(self.tblSplits)
        self.tabHistorical.addTab(self.tabSplits, "")
        self.horizontalLayout_5.addWidget(self.tabHistorical)
        self.verticalLayout_7.addWidget(self.groupBox_9)
        self.horizontalLayout_37.addLayout(self.verticalLayout_7)
        self.tab.addTab(self.tabQuotes, "")
        self.tabOther = QtWidgets.QWidget()
        self.tabOther.setObjectName("tabOther")
        self.horizontalLayout_12 = QtWidgets.QHBoxLayout(self.tabOther)
        self.horizontalLayout_12.setObjectName("horizontalLayout_12")
        self.tabEstimaciones = QtWidgets.QTabWidget(self.tabOther)
        self.tabEstimaciones.setObjectName("tabEstimaciones")
        self.tab_2 = QtWidgets.QWidget()
        self.tab_2.setObjectName("tab_2")
        self.horizontalLayout_40 = QtWidgets.QHBoxLayout(self.tab_2)
        self.horizontalLayout_40.setObjectName("horizontalLayout_40")
        self.tblDPSPaid = myQTableWidget(self.tab_2)
        self.tblDPSPaid.setContextMenuPolicy(QtCore.Qt.CustomContextMenu)
        self.tblDPSPaid.setAlternatingRowColors(True)
        self.tblDPSPaid.setSelectionBehavior(QtWidgets.QAbstractItemView.SelectRows)
        self.tblDPSPaid.setObjectName("tblDPSPaid")
        self.tblDPSPaid.setColumnCount(0)
        self.tblDPSPaid.setRowCount(0)
        self.tblDPSPaid.verticalHeader().setVisible(False)
        self.horizontalLayout_40.addWidget(self.tblDPSPaid)
        icon8 = QtGui.QIcon()
        icon8.addPixmap(QtGui.QPixmap(":/xulpymoney/coins.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.tabEstimaciones.addTab(self.tab_2, icon8, "")
        self.tab_8 = QtWidgets.QWidget()
        self.tab_8.setObjectName("tab_8")
        self.horizontalLayout_13 = QtWidgets.QHBoxLayout(self.tab_8)
        self.horizontalLayout_13.setObjectName("horizontalLayout_13")
        self.tblDividendsEstimations = myQTableWidget(self.tab_8)
        self.tblDividendsEstimations.setContextMenuPolicy(QtCore.Qt.CustomContextMenu)
        self.tblDividendsEstimations.setAlternatingRowColors(True)
        self.tblDividendsEstimations.setSelectionBehavior(QtWidgets.QAbstractItemView.SelectRows)
        self.tblDividendsEstimations.setObjectName("tblDividendsEstimations")
        self.tblDividendsEstimations.setColumnCount(6)
        self.tblDividendsEstimations.setRowCount(0)
        item = QtWidgets.QTableWidgetItem()
        self.tblDividendsEstimations.setHorizontalHeaderItem(0, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblDividendsEstimations.setHorizontalHeaderItem(1, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblDividendsEstimations.setHorizontalHeaderItem(2, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblDividendsEstimations.setHorizontalHeaderItem(3, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblDividendsEstimations.setHorizontalHeaderItem(4, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblDividendsEstimations.setHorizontalHeaderItem(5, item)
        self.tblDividendsEstimations.verticalHeader().setVisible(False)
        self.horizontalLayout_13.addWidget(self.tblDividendsEstimations)
        self.tabEstimaciones.addTab(self.tab_8, icon8, "")
        self.tab_9 = QtWidgets.QWidget()
        self.tab_9.setObjectName("tab_9")
        self.horizontalLayout_20 = QtWidgets.QHBoxLayout(self.tab_9)
        self.horizontalLayout_20.setObjectName("horizontalLayout_20")
        self.tblEPS = myQTableWidget(self.tab_9)
        self.tblEPS.setContextMenuPolicy(QtCore.Qt.CustomContextMenu)
        self.tblEPS.setAlternatingRowColors(True)
        self.tblEPS.setSelectionBehavior(QtWidgets.QAbstractItemView.SelectRows)
        self.tblEPS.setObjectName("tblEPS")
        self.tblEPS.setColumnCount(6)
        self.tblEPS.setRowCount(0)
        item = QtWidgets.QTableWidgetItem()
        self.tblEPS.setHorizontalHeaderItem(0, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblEPS.setHorizontalHeaderItem(1, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblEPS.setHorizontalHeaderItem(2, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblEPS.setHorizontalHeaderItem(3, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblEPS.setHorizontalHeaderItem(4, item)
        item = QtWidgets.QTableWidgetItem()
        self.tblEPS.setHorizontalHeaderItem(5, item)
        self.tblEPS.verticalHeader().setVisible(False)
        self.horizontalLayout_20.addWidget(self.tblEPS)
        icon9 = QtGui.QIcon()
        icon9.addPixmap(QtGui.QPixmap(":/xulpymoney/star.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.tabEstimaciones.addTab(self.tab_9, icon9, "")
        self.horizontalLayout_12.addWidget(self.tabEstimaciones)
        self.tab.addTab(self.tabOther, "")
        self.verticalLayout.addWidget(self.tab)
        self.horizontalLayout_22.addLayout(self.verticalLayout)
        self.actionQuoteNew = QtWidgets.QAction(frmProductReport)
        icon10 = QtGui.QIcon()
        icon10.addPixmap(QtGui.QPixmap(":/xulpymoney/add.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionQuoteNew.setIcon(icon10)
        self.actionQuoteNew.setObjectName("actionQuoteNew")
        self.actionQuoteDelete = QtWidgets.QAction(frmProductReport)
        icon11 = QtGui.QIcon()
        icon11.addPixmap(QtGui.QPixmap(":/xulpymoney/list-remove.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionQuoteDelete.setIcon(icon11)
        self.actionQuoteDelete.setObjectName("actionQuoteDelete")
        self.actionEstimationDPSNew = QtWidgets.QAction(frmProductReport)
        self.actionEstimationDPSNew.setIcon(icon10)
        self.actionEstimationDPSNew.setObjectName("actionEstimationDPSNew")
        self.actionEstimationDPSDelete = QtWidgets.QAction(frmProductReport)
        self.actionEstimationDPSDelete.setIcon(icon11)
        self.actionEstimationDPSDelete.setObjectName("actionEstimationDPSDelete")
        self.actionPurgeDay = QtWidgets.QAction(frmProductReport)
        self.actionPurgeDay.setIcon(icon7)
        self.actionPurgeDay.setObjectName("actionPurgeDay")
        self.actionQuoteEdit = QtWidgets.QAction(frmProductReport)
        icon12 = QtGui.QIcon()
        icon12.addPixmap(QtGui.QPixmap(":/xulpymoney/editar.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionQuoteEdit.setIcon(icon12)
        self.actionQuoteEdit.setObjectName("actionQuoteEdit")
        self.actionEstimationEPSNew = QtWidgets.QAction(frmProductReport)
        self.actionEstimationEPSNew.setIcon(icon10)
        self.actionEstimationEPSNew.setObjectName("actionEstimationEPSNew")
        self.actionEstimationEPSDelete = QtWidgets.QAction(frmProductReport)
        self.actionEstimationEPSDelete.setIcon(icon11)
        self.actionEstimationEPSDelete.setObjectName("actionEstimationEPSDelete")
        self.actionDPSNew = QtWidgets.QAction(frmProductReport)
        self.actionDPSNew.setIcon(icon10)
        self.actionDPSNew.setObjectName("actionDPSNew")
        self.actionDPSDelete = QtWidgets.QAction(frmProductReport)
        self.actionDPSDelete.setIcon(icon11)
        self.actionDPSDelete.setObjectName("actionDPSDelete")
        self.actionDividendXuNew = QtWidgets.QAction(frmProductReport)
        self.actionDividendXuNew.setIcon(icon8)
        self.actionDividendXuNew.setObjectName("actionDividendXuNew")
        self.actionQuoteDeleteDays = QtWidgets.QAction(frmProductReport)
        self.actionQuoteDeleteDays.setIcon(icon11)
        self.actionQuoteDeleteDays.setObjectName("actionQuoteDeleteDays")
        self.actionQuoteDeleteMonths = QtWidgets.QAction(frmProductReport)
        self.actionQuoteDeleteMonths.setIcon(icon11)
        self.actionQuoteDeleteMonths.setObjectName("actionQuoteDeleteMonths")
        self.actionQuoteDeleteYears = QtWidgets.QAction(frmProductReport)
        self.actionQuoteDeleteYears.setIcon(icon11)
        self.actionQuoteDeleteYears.setObjectName("actionQuoteDeleteYears")
        self.actionQuoteImport = QtWidgets.QAction(frmProductReport)
        icon13 = QtGui.QIcon()
        icon13.addPixmap(QtGui.QPixmap(":/xulpymoney/libreoffice_calc.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionQuoteImport.setIcon(icon13)
        self.actionQuoteImport.setObjectName("actionQuoteImport")
        self.actionSplitNew = QtWidgets.QAction(frmProductReport)
        self.actionSplitNew.setIcon(icon10)
        self.actionSplitNew.setObjectName("actionSplitNew")
        self.actionSplitRemove = QtWidgets.QAction(frmProductReport)
        self.actionSplitRemove.setIcon(icon11)
        self.actionSplitRemove.setObjectName("actionSplitRemove")
        self.actionSplitEdit = QtWidgets.QAction(frmProductReport)
        self.actionSplitEdit.setIcon(icon12)
        self.actionSplitEdit.setObjectName("actionSplitEdit")
        self.actionDPSImport = QtWidgets.QAction(frmProductReport)
        self.actionDPSImport.setIcon(icon13)
        self.actionDPSImport.setObjectName("actionDPSImport")
        self.actionQuoteExport = QtWidgets.QAction(frmProductReport)
        self.actionQuoteExport.setIcon(icon13)
        self.actionQuoteExport.setObjectName("actionQuoteExport")

        self.retranslateUi(frmProductReport)
        self.tab.setCurrentIndex(0)
        self.tabGraphics.setCurrentIndex(0)
        self.tabHistorical.setCurrentIndex(4)
        self.tabEstimaciones.setCurrentIndex(0)
        QtCore.QMetaObject.connectSlotsByName(frmProductReport)

    def retranslateUi(self, frmProductReport):
        _translate = QtCore.QCoreApplication.translate
        frmProductReport.setWindowTitle(_translate("frmProductReport", "Product report"))
        self.grpInformation.setTitle(_translate("frmProductReport", "Information"))
        self.label.setText(_translate("frmProductReport", "Product name"))
        self.label_10.setText(_translate("frmProductReport", "ISIN code"))
        self.label_9.setText(_translate("frmProductReport", "Currency"))
        self.label_12.setText(_translate("frmProductReport", "Product type"))
        self.label_16.setText(_translate("frmProductReport", "Stock exchange"))
        self.label_13.setText(_translate("frmProductReport", "Agrupations"))
        self.label_3.setText(_translate("frmProductReport", "Web page"))
        self.label_4.setText(_translate("frmProductReport", "Address"))
        self.lblMail.setText(_translate("frmProductReport", "Email"))
        self.label_14.setText(_translate("frmProductReport", "Variable percentage"))
        self.txtTPC.setText(_translate("frmProductReport", "100"))
        self.label_22.setText(_translate("frmProductReport", "Put / Call / Inline"))
        self.label_5.setText(_translate("frmProductReport", "Telephone"))
        self.label_15.setText(_translate("frmProductReport", "Leveraged"))
        self.label_11.setText(_translate("frmProductReport", "Tickers"))
        item = self.tblTickers.verticalHeaderItem(0)
        item.setText(_translate("frmProductReport", "Yahoo"))
        item = self.tblTickers.verticalHeaderItem(1)
        item.setText(_translate("frmProductReport", "Morningstar"))
        item = self.tblTickers.verticalHeaderItem(2)
        item.setText(_translate("frmProductReport", "Google"))
        item = self.tblTickers.verticalHeaderItem(3)
        item.setText(_translate("frmProductReport", "QueFondos"))
        item = self.tblTickers.horizontalHeaderItem(0)
        item.setText(_translate("frmProductReport", "Value"))
        __sortingEnabled = self.tblTickers.isSortingEnabled()
        self.tblTickers.setSortingEnabled(False)
        self.tblTickers.setSortingEnabled(__sortingEnabled)
        self.label_21.setText(_translate("frmProductReport", "Comment"))
        self.chkHL.setText(_translate("frmProductReport", "Allow short and long contracts"))
        self.chkObsolete.setText(_translate("frmProductReport", "Obsolete product"))
        self.cmdSave.setText(_translate("frmProductReport", "Update investment"))
        self.tab.setTabText(self.tab.indexOf(self.tabInformacion), _translate("frmProductReport", "Investment information"))
        self.groupBox_3.setTitle(_translate("frmProductReport", "Product prices"))
        self.grpGraphIntraday.setTitle(_translate("frmProductReport", "Daily prices graph"))
        self.tabGraphics.setTabText(self.tabGraphics.indexOf(self.tabGraphicsIntraday), _translate("frmProductReport", "Daily"))
        self.groupBox_2.setTitle(_translate("frmProductReport", "Historical prices graph"))
        self.tabGraphics.setTabText(self.tabGraphics.indexOf(self.tabGraphicsHistorical), _translate("frmProductReport", "Historical"))
        self.tab.setTabText(self.tab.indexOf(self.tabGraficos), _translate("frmProductReport", "Charts"))
        self.grpHistoricos.setTitle(_translate("frmProductReport", "Report of historic prices"))
        item = self.tblTPC.verticalHeaderItem(0)
        item.setText(_translate("frmProductReport", "Last price"))
        item = self.tblTPC.verticalHeaderItem(2)
        item.setText(_translate("frmProductReport", "Daily variation"))
        item = self.tblTPC.verticalHeaderItem(3)
        item.setText(_translate("frmProductReport", "Weekly variation"))
        item = self.tblTPC.verticalHeaderItem(4)
        item.setText(_translate("frmProductReport", "Monthly variation"))
        item = self.tblTPC.verticalHeaderItem(5)
        item.setText(_translate("frmProductReport", "Annual variation"))
        item = self.tblTPC.verticalHeaderItem(7)
        item.setText(_translate("frmProductReport", "Last 7 days variation"))
        item = self.tblTPC.verticalHeaderItem(8)
        item.setText(_translate("frmProductReport", "Last 30 days variation"))
        item = self.tblTPC.verticalHeaderItem(9)
        item.setText(_translate("frmProductReport", "Last 12 months variation"))
        item = self.tblTPC.horizontalHeaderItem(0)
        item.setText(_translate("frmProductReport", "Date"))
        item = self.tblTPC.horizontalHeaderItem(1)
        item.setText(_translate("frmProductReport", "Price"))
        item = self.tblTPC.horizontalHeaderItem(2)
        item.setText(_translate("frmProductReport", "%"))
        item = self.tblTPC.horizontalHeaderItem(3)
        item.setText(_translate("frmProductReport", "% APR"))
        item = self.tblTPC.horizontalHeaderItem(4)
        item.setText(_translate("frmProductReport", "Gains"))
        __sortingEnabled = self.tblTPC.isSortingEnabled()
        self.tblTPC.setSortingEnabled(False)
        self.tblTPC.setSortingEnabled(__sortingEnabled)
        self.cmdPurge.setToolTip(_translate("frmProductReport", "Purge investment from innecesary quotes. Leaves high, low, open and close quotes"))
        self.cmdPurge.setText(_translate("frmProductReport", "Purge investment"))
        self.cmdSplitManual.setText(_translate("frmProductReport", "Adjust Split / Contrasplit manually in prices"))
        self.groupBox_9.setTitle(_translate("frmProductReport", "Product prices"))
        item = self.tblDaily.horizontalHeaderItem(0)
        item.setText(_translate("frmProductReport", "Date"))
        item = self.tblDaily.horizontalHeaderItem(1)
        item.setText(_translate("frmProductReport", "Price"))
        item = self.tblDaily.horizontalHeaderItem(2)
        item.setText(_translate("frmProductReport", "Open"))
        item = self.tblDaily.horizontalHeaderItem(3)
        item.setText(_translate("frmProductReport", "Higher"))
        item = self.tblDaily.horizontalHeaderItem(4)
        item.setText(_translate("frmProductReport", "Lower"))
        item = self.tblDaily.horizontalHeaderItem(5)
        item.setText(_translate("frmProductReport", "Agrupation Start"))
        self.label_6.setText(_translate("frmProductReport", "Splits and dividends hasn\'t been adjusted in this prices. They are database prices"))
        self.tabHistorical.setTabText(self.tabHistorical.indexOf(self.tab_5), _translate("frmProductReport", "Daily prices "))
        item = self.tblWeekly.horizontalHeaderItem(0)
        item.setText(_translate("frmProductReport", "Date"))
        item = self.tblWeekly.horizontalHeaderItem(1)
        item.setText(_translate("frmProductReport", "Price"))
        item = self.tblWeekly.horizontalHeaderItem(2)
        item.setText(_translate("frmProductReport", "Open"))
        item = self.tblWeekly.horizontalHeaderItem(3)
        item.setText(_translate("frmProductReport", "Higher"))
        item = self.tblWeekly.horizontalHeaderItem(4)
        item.setText(_translate("frmProductReport", "Lower"))
        item = self.tblWeekly.horizontalHeaderItem(5)
        item.setText(_translate("frmProductReport", "Agrupation start"))
        self.label_8.setText(_translate("frmProductReport", "Splits and dividends hasn\'t been adjusted in this prices. They are database prices"))
        self.tabHistorical.setTabText(self.tabHistorical.indexOf(self.tab_14), _translate("frmProductReport", "Weekly prices"))
        item = self.tblMonthly.horizontalHeaderItem(0)
        item.setText(_translate("frmProductReport", "Date"))
        item = self.tblMonthly.horizontalHeaderItem(1)
        item.setText(_translate("frmProductReport", "Price"))
        item = self.tblMonthly.horizontalHeaderItem(2)
        item.setText(_translate("frmProductReport", "Open"))
        item = self.tblMonthly.horizontalHeaderItem(3)
        item.setText(_translate("frmProductReport", "Higher"))
        item = self.tblMonthly.horizontalHeaderItem(4)
        item.setText(_translate("frmProductReport", "Lower"))
        item = self.tblMonthly.horizontalHeaderItem(5)
        item.setText(_translate("frmProductReport", "Agrupation start"))
        self.label_17.setText(_translate("frmProductReport", "Splits and dividends hasn\'t been adjusted in this prices. They are database prices"))
        self.tabHistorical.setTabText(self.tabHistorical.indexOf(self.tab_3), _translate("frmProductReport", "Monthly prices"))
        item = self.tblYearly.horizontalHeaderItem(0)
        item.setText(_translate("frmProductReport", "Date"))
        item = self.tblYearly.horizontalHeaderItem(1)
        item.setText(_translate("frmProductReport", "Price"))
        item = self.tblYearly.horizontalHeaderItem(2)
        item.setText(_translate("frmProductReport", "Open"))
        item = self.tblYearly.horizontalHeaderItem(3)
        item.setText(_translate("frmProductReport", "Higher"))
        item = self.tblYearly.horizontalHeaderItem(4)
        item.setText(_translate("frmProductReport", "Lower"))
        item = self.tblYearly.horizontalHeaderItem(5)
        item.setText(_translate("frmProductReport", "Agrupation start"))
        self.label_18.setText(_translate("frmProductReport", "Splits and dividends hasn\'t been adjusted in this prices. They are database prices"))
        self.tabHistorical.setTabText(self.tabHistorical.indexOf(self.tab_13), _translate("frmProductReport", "Annual prices"))
        self.tblMensuales.setToolTip(_translate("frmProductReport", "Table has been calculted with the last price of the previous month and the last price of the corresponding month"))
        item = self.tblMensuales.horizontalHeaderItem(0)
        item.setText(_translate("frmProductReport", "Year"))
        item = self.tblMensuales.horizontalHeaderItem(1)
        item.setText(_translate("frmProductReport", "January"))
        item = self.tblMensuales.horizontalHeaderItem(2)
        item.setText(_translate("frmProductReport", "February"))
        item = self.tblMensuales.horizontalHeaderItem(3)
        item.setText(_translate("frmProductReport", "March"))
        item = self.tblMensuales.horizontalHeaderItem(4)
        item.setText(_translate("frmProductReport", "April"))
        item = self.tblMensuales.horizontalHeaderItem(5)
        item.setText(_translate("frmProductReport", "May"))
        item = self.tblMensuales.horizontalHeaderItem(6)
        item.setText(_translate("frmProductReport", "June"))
        item = self.tblMensuales.horizontalHeaderItem(7)
        item.setText(_translate("frmProductReport", "July"))
        item = self.tblMensuales.horizontalHeaderItem(8)
        item.setText(_translate("frmProductReport", "August"))
        item = self.tblMensuales.horizontalHeaderItem(9)
        item.setText(_translate("frmProductReport", "September"))
        item = self.tblMensuales.horizontalHeaderItem(10)
        item.setText(_translate("frmProductReport", "October"))
        item = self.tblMensuales.horizontalHeaderItem(11)
        item.setText(_translate("frmProductReport", "November"))
        item = self.tblMensuales.horizontalHeaderItem(12)
        item.setText(_translate("frmProductReport", "December"))
        item = self.tblMensuales.horizontalHeaderItem(13)
        item.setText(_translate("frmProductReport", "Total"))
        self.label_19.setText(_translate("frmProductReport", "These percentages have been calculated with prices with adjusted splits"))
        self.tabHistorical.setTabText(self.tabHistorical.indexOf(self.tab_6), _translate("frmProductReport", "Monthly returns"))
        self.tabHistorical.setTabText(self.tabHistorical.indexOf(self.tabSplits), _translate("frmProductReport", "Splits / Contrasplits"))
        self.tab.setTabText(self.tab.indexOf(self.tabQuotes), _translate("frmProductReport", "Historical prices"))
        self.tabEstimaciones.setTabText(self.tabEstimaciones.indexOf(self.tab_2), _translate("frmProductReport", "DPS Paid"))
        item = self.tblDividendsEstimations.horizontalHeaderItem(0)
        item.setText(_translate("frmProductReport", "Year"))
        item = self.tblDividendsEstimations.horizontalHeaderItem(1)
        item.setText(_translate("frmProductReport", "Price"))
        item = self.tblDividendsEstimations.horizontalHeaderItem(2)
        item.setText(_translate("frmProductReport", "%"))
        item = self.tblDividendsEstimations.horizontalHeaderItem(3)
        item.setText(_translate("frmProductReport", "Annotation date"))
        item = self.tblDividendsEstimations.horizontalHeaderItem(4)
        item.setText(_translate("frmProductReport", "Source"))
        item = self.tblDividendsEstimations.horizontalHeaderItem(5)
        item.setText(_translate("frmProductReport", "Manual"))
        self.tabEstimaciones.setTabText(self.tabEstimaciones.indexOf(self.tab_8), _translate("frmProductReport", "DPS Estimations"))
        item = self.tblEPS.horizontalHeaderItem(0)
        item.setText(_translate("frmProductReport", "Year"))
        item = self.tblEPS.horizontalHeaderItem(1)
        item.setText(_translate("frmProductReport", "Price"))
        item = self.tblEPS.horizontalHeaderItem(2)
        item.setText(_translate("frmProductReport", "PER"))
        item = self.tblEPS.horizontalHeaderItem(3)
        item.setText(_translate("frmProductReport", "Annotation date"))
        item = self.tblEPS.horizontalHeaderItem(4)
        item.setText(_translate("frmProductReport", "Source"))
        item = self.tblEPS.horizontalHeaderItem(5)
        item.setText(_translate("frmProductReport", "Manual"))
        self.tabEstimaciones.setTabText(self.tabEstimaciones.indexOf(self.tab_9), _translate("frmProductReport", "EPS Estimations"))
        self.tab.setTabText(self.tab.indexOf(self.tabOther), _translate("frmProductReport", "Other data"))
        self.actionQuoteNew.setText(_translate("frmProductReport", "New price"))
        self.actionQuoteNew.setToolTip(_translate("frmProductReport", "New price"))
        self.actionQuoteDelete.setText(_translate("frmProductReport", "Delete price from selected day"))
        self.actionQuoteDelete.setToolTip(_translate("frmProductReport", "Delete price from selected day"))
        self.actionEstimationDPSNew.setText(_translate("frmProductReport", "New dividend per share estimation"))
        self.actionEstimationDPSNew.setToolTip(_translate("frmProductReport", "New dividend per share estimation"))
        self.actionEstimationDPSDelete.setText(_translate("frmProductReport", "Remove dividend per share estimation"))
        self.actionEstimationDPSDelete.setToolTip(_translate("frmProductReport", "Remove dividend per share estimation"))
        self.actionPurgeDay.setText(_translate("frmProductReport", "Purge Day"))
        self.actionPurgeDay.setToolTip(_translate("frmProductReport", "Purge Day from innecesary quotes. Leaves high, low, open and close quotes"))
        self.actionQuoteEdit.setText(_translate("frmProductReport", "Edit Quote"))
        self.actionQuoteEdit.setToolTip(_translate("frmProductReport", "Edit Quote"))
        self.actionEstimationEPSNew.setText(_translate("frmProductReport", "New earnings per share estimation"))
        self.actionEstimationEPSNew.setToolTip(_translate("frmProductReport", "New earnings per share estimation"))
        self.actionEstimationEPSDelete.setText(_translate("frmProductReport", "Remove earnings per share estimation"))
        self.actionEstimationEPSDelete.setToolTip(_translate("frmProductReport", "Remove earnings per share estimation"))
        self.actionDPSNew.setText(_translate("frmProductReport", "New DPS"))
        self.actionDPSNew.setToolTip(_translate("frmProductReport", "New DPS"))
        self.actionDPSDelete.setText(_translate("frmProductReport", "Remove DPS"))
        self.actionDPSDelete.setToolTip(_translate("frmProductReport", "Remove DPS"))
        self.actionDividendXuNew.setText(_translate("frmProductReport", "Selected investment dividend"))
        self.actionDividendXuNew.setToolTip(_translate("frmProductReport", "Selected investment dividend"))
        self.actionQuoteDeleteDays.setText(_translate("frmProductReport", "Delete all prices from selected day"))
        self.actionQuoteDeleteDays.setToolTip(_translate("frmProductReport", "Delete all prices from selected day"))
        self.actionQuoteDeleteMonths.setText(_translate("frmProductReport", "Delete all prices from selected month"))
        self.actionQuoteDeleteMonths.setToolTip(_translate("frmProductReport", "Delete all prices from selected month"))
        self.actionQuoteDeleteYears.setText(_translate("frmProductReport", "Delete all prices from selected year"))
        self.actionQuoteDeleteYears.setToolTip(_translate("frmProductReport", "Delete all prices from selected year"))
        self.actionQuoteImport.setText(_translate("frmProductReport", "Import quotes from Libreoffice ODS"))
        self.actionQuoteImport.setToolTip(_translate("frmProductReport", "Needs a file with first sheet with two columns. Date/Datetime in ISO Format  and value"))
        self.actionSplitNew.setText(_translate("frmProductReport", "New Split / Contrasplit"))
        self.actionSplitNew.setToolTip(_translate("frmProductReport", "New Split / Contrasplit"))
        self.actionSplitRemove.setText(_translate("frmProductReport", "Remove Split / Contrasplit"))
        self.actionSplitRemove.setToolTip(_translate("frmProductReport", "Remove Split / Contrasplit"))
        self.actionSplitEdit.setText(_translate("frmProductReport", "Edit Split / Contrasplit"))
        self.actionSplitEdit.setToolTip(_translate("frmProductReport", "Edit Split / Contrasplit"))
        self.actionDPSImport.setText(_translate("frmProductReport", "Import dividend per share from Libreoffice ODS"))
        self.actionDPSImport.setToolTip(_translate("frmProductReport", "Needs a file with first sheet with two columns. Date/Datetime in ISO Format  and value"))
        self.actionQuoteExport.setText(_translate("frmProductReport", "Export quotes to Libreoffice ODS"))
        self.actionQuoteExport.setToolTip(_translate("frmProductReport", "Export quotes to Libreoffice ODS"))


from xulpymoney.ui.myqtablewidget import myQTableWidget
import xulpymoney.images.xulpymoney_rc



from PyQt5.QtCore import pyqtSignal, pyqtSlot
from PyQt5.QtWidgets import QLineEdit, QWidget
from decimal import Decimal

class myQLineEdit(QLineEdit):
    doubleClicked=pyqtSignal()
    def __init__(self, parent):
        QWidget.__init__(self, parent)       
#        self.setValidator(QDoubleValidator(self)) ##Failed to show point from numerical pad
        self.textChanged.connect(self.on_textChanged)
        self.setMaxLength(30)
        
        
    def isValid(self):
        """Devuelve si el textedit es un float o un decimal valido"""
        if self.decimal()==None:
            return False
        return True
            
    def setBackgroundRed(self, red):
        if red==True:
            css = """QLineEdit { background-color: rgb(255, 182, 182); }"""
        else:
            css=""
        self.setStyleSheet(css)
 
    @pyqtSlot(str)
    def on_textChanged(self, text):
        pos=self.cursorPosition()
        text=text.replace(",", ".")
        text=text.replace("e", "0")#Avoids scientific numbers
        self.setText(text)
        if self.isValid():        
            self.setBackgroundRed(False)
        else:
            self.setBackgroundRed(True)
        self.setCursorPosition(pos)     
        
#    def keyReleaseEvent(self, event):
#        super(myQLineEdit, self).keyReleaseEvent(event)
#        if event.text() in ("0123456789.,"):
#            print("acepted")
#            event.accept()
#            return
#        print ("ignore")
#        print (event.text())
#        event.ignore()
        
    def decimal(self):
        """Devuelve el decimal o un None si hay error"""
        try:
            #Due to database precision (18,6) debe redondear a 10^12
            a=Decimal(self.text())
            if a<Decimal(1000000000000):
                return a
            else:
                return None
        except:
            return None

    def float(self):
        try:
            return float(self.text())
        except:
            return None
            
    def setText(self, num):
        """This funcion  overrides QLineEdit settext and lets enter numbers, int, float, decimals"""
        super(myQLineEdit, self).setText(str(num))
        

    def mouseDoubleClickEvent(self, event):
        print("MOUSEDOUBLECLICKEVENT")
        self.doubleClicked.emit()
        print("EMITEED")
